-- ALTER STATEMENTS

ALTER TABLE Trace.InitialEvent DROP CONSTRAINT InitialEvent_FK;

ALTER TABLE Trace.Trace_Transfer DROP CONSTRAINT Transfer_Trace_FK;

ALTER TABLE Trace.Trace_Fragment DROP CONSTRAINT Fragment_Trace_FK;

ALTER TABLE Trace.Error DROP CONSTRAINT Error_Event_FK;

ALTER TABLE Trace.Trace_Transfer DROP CONSTRAINT Transfer_LEvent_FK;

ALTER TABLE Trace.Trace_Fragment DROP CONSTRAINT Fragment_LEvent_FK;

ALTER TABLE Trace.Message DROP CONSTRAINT MessageCategory_FK;

ALTER TABLE Trace.Trace DROP CONSTRAINT InitialEvent_FK;

ALTER TABLE Trace.Error DROP CONSTRAINT Error_Message_FK;

ALTER TABLE Trace.LinkEvent DROP CONSTRAINT LinkEvent_Event_FK;

ALTER TABLE Trace.LinkEvent DROP CONSTRAINT LinkEvent_PK;

ALTER TABLE Trace.Event DROP CONSTRAINT Event_PK;

ALTER TABLE Trace.InitialEvent DROP CONSTRAINT InitialEvent_PK;

ALTER TABLE Trace.Trace DROP CONSTRAINT Trace_PK;

ALTER TABLE Trace.Trace_Fragment DROP CONSTRAINT Trace_Fragment_PK;

ALTER TABLE Trace.Error DROP CONSTRAINT Error_PK;

ALTER TABLE Trace.Trace_Transfer DROP CONSTRAINT Trace_Transfer_PK;

ALTER TABLE Trace.MessageCategory DROP CONSTRAINT MessageCategory_PK;

ALTER TABLE Trace.Message DROP CONSTRAINT Message_PK;

ALTER TABLE Trace.ContainerFullDisaggregations DROP CONSTRAINT Trace_FllDsggs_PK;

ALTER TABLE Trace.Containments DROP CONSTRAINT Trace_Cntnmnts_CK1;



-- DROP STATEMENTS

DROP INDEX Trace.trace_epc_idx;

DROP INDEX Trace.Containments_parent_epc_IDX;

DROP INDEX Trace.Containments_child_epc_IDX;

DROP TABLE Trace.Containments;

DROP TABLE Trace.ContainerFullDisaggregations;

DROP TABLE Trace.MessageCategory;

DROP TABLE Trace.Trace_Transfer;

DROP TABLE Trace.Trace_Fragment;

DROP TABLE Trace.LinkEvent;

DROP TABLE Trace.Message;

DROP TABLE Trace.Trace;

DROP TABLE Trace.Event;

DROP TABLE Trace.InitialEvent;

DROP TABLE Trace.Error;

-- report tables

-- ALTER TABLE Trace.Report DROP CONSTRAINT Report_SourceObject_FK;
ALTER TABLE Trace.Report DROP CONSTRAINT ErrorReport_PK;
ALTER TABLE Trace.ReportEpc DROP CONSTRAINT Report_Epc_FK;
    
DROP TABLE Trace.Report;
DROP TABLE Trace.ReportEpc;
DROP TABLE Trace.ReportInput;

DROP SCHEMA Trace RESTRICT;


-- CREATE STATEMENTS
-- if a tablespace is specified at the table level, then ${storage_opts} = IN tablespace_x

CREATE SCHEMA Trace;

CREATE TABLE Trace.MessageCategory (
		code CHAR(10) NOT NULL,
		title VARCHAR(100)
	) ${storage_opts};

CREATE TABLE Trace.Message (
		code CHAR(10) NOT NULL,
		category CHAR(10) NOT NULL,
		title VARCHAR(100)
	) ${storage_opts};

CREATE TABLE Trace.Event (
		id_Event INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1, CACHE 25),
		eventType INTEGER NOT NULL,
		eventTime TIMESTAMP NOT NULL,
		eventSource VARCHAR(100) NOT NULL
	) ${storage_opts};

CREATE TABLE Trace.Error (
		id_Event INTEGER NOT NULL,
		code CHAR(10) NOT NULL,
		args LONG VARCHAR
	) ${storage_opts};

CREATE TABLE Trace.InitialEvent (
		id_Event INTEGER NOT NULL,
		productId VARCHAR(100)
	) ${storage_opts};

CREATE TABLE Trace.Trace (
		id_Trace INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1, CACHE 25),
		id_initialEvent INTEGER,
		epc VARCHAR(100) NOT NULL,
		status INTEGER NOT NULL
	) ${storage_opts};

CREATE TABLE Trace.LinkEvent (
		id_Event INTEGER NOT NULL,
		physicalSource VARCHAR(100) NOT NULL,
		bizSource VARCHAR(100) NOT NULL,
		physicalDestination VARCHAR(100) NOT NULL,
		bizDestination VARCHAR(100),
		contactId VARCHAR(100)--,
		--eventEpc VARCHAR(100)
	) ${storage_opts};

CREATE TABLE Trace.Trace_Fragment (
		id_Trace INTEGER NOT NULL,
		id_Event INTEGER NOT NULL,
		sequence INTEGER NOT NULL
	) ${storage_opts};

CREATE TABLE Trace.Trace_Transfer (
		id_Trace INTEGER NOT NULL,
		id_Event INTEGER NOT NULL,
		sequence INTEGER NOT NULL
	) ${storage_opts};
	
	
CREATE INDEX Trace.trace_epc_idx ON Trace.Trace(epc);	

CREATE TABLE Trace.Containments (
		parent_epc VARCHAR(100) NOT NULL,
		child_epc VARCHAR(100) NOT NULL,
		child_is_container CHAR(1) DEFAULT 'f' NOT NULL,
		aggregation_time TIMESTAMP,
		disaggregation_time TIMESTAMP
	) ${storage_opts};
	
CREATE TABLE Trace.ContainerFullDisaggregations (
		parent_epc VARCHAR(100) NOT NULL,
		disaggregation_time TIMESTAMP NOT NULL
	) ${storage_opts};	
	
	
-- Report tables

CREATE TABLE TRACE.REPORT (
        ID_REPORT INTEGER  NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1, CACHE 25),
        ID_SRCOBJECT VARCHAR(256) NOT NULL,
        SRCOPERATION VARCHAR(256) NOT NULL,
        ERRORTEXT VARCHAR(2048) NOT NULL,
        ERRORDETAIL VARCHAR(4000),
        ERRORTIME TIMESTAMP NOT NULL
    ) ${storage_opts};

CREATE TABLE TRACE.REPORTEPC (
        ID_REPORT INTEGER NOT NULL,
        EPC VARCHAR(256) NOT NULL
    ) ${storage_opts};

CREATE TABLE TRACE.REPORTINPUT (
        ID_SRCOBJECT VARCHAR(256) NOT NULL,
        SRCOBJECT CLOB(1G)
    ) ${storage_opts};


ALTER TABLE Trace.MessageCategory ADD CONSTRAINT MessageCategory_PK PRIMARY KEY (code);

ALTER TABLE Trace.Message ADD CONSTRAINT Message_PK PRIMARY KEY (code);

ALTER TABLE Trace.Event ADD CONSTRAINT Event_PK PRIMARY KEY (id_Event);

ALTER TABLE Trace.Error ADD CONSTRAINT Error_PK PRIMARY KEY (id_Event, code);

ALTER TABLE Trace.InitialEvent ADD CONSTRAINT InitialEvent_PK PRIMARY KEY (id_Event);

ALTER TABLE Trace.Trace ADD CONSTRAINT Trace_PK PRIMARY KEY (id_Trace);

ALTER TABLE Trace.LinkEvent ADD CONSTRAINT LinkEvent_PK PRIMARY KEY (id_Event);

ALTER TABLE Trace.Trace_Fragment ADD CONSTRAINT Trace_Fragment_PK PRIMARY KEY (id_Trace, id_Event);

ALTER TABLE Trace.Trace_Transfer ADD CONSTRAINT Trace_Transfer_PK PRIMARY KEY (id_Trace, id_Event);

ALTER TABLE Trace.Containments ADD CONSTRAINT Trace_Cntnmnts_CK1 CHECK (child_is_container IN ('t', 'f'));

ALTER TABLE Trace.ContainerFullDisaggregations ADD CONSTRAINT Trace_FllDsggs_PK PRIMARY KEY (parent_epc, disaggregation_time);

ALTER TABLE Trace.Message ADD CONSTRAINT MessageCategory_FK FOREIGN KEY (category)
	REFERENCES Trace.MessageCategory (code)
	ON DELETE CASCADE;

ALTER TABLE Trace.Error ADD CONSTRAINT Error_Event_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.Event (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.Error ADD CONSTRAINT Error_Message_FK FOREIGN KEY (code)
	REFERENCES Trace.Message (code)
	ON DELETE CASCADE;

ALTER TABLE Trace.InitialEvent ADD CONSTRAINT InitialEvent_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.Event (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace ADD CONSTRAINT InitialEvent_FK FOREIGN KEY (id_initialEvent)
	REFERENCES Trace.InitialEvent (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.LinkEvent ADD CONSTRAINT LinkEvent_Event_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.Event (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace_Fragment ADD CONSTRAINT Fragment_Trace_FK FOREIGN KEY (id_Trace)
	REFERENCES Trace.Trace (id_Trace)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace_Fragment ADD CONSTRAINT Fragment_LEvent_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.LinkEvent (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace_Transfer ADD CONSTRAINT Transfer_Trace_FK FOREIGN KEY (id_Trace)
	REFERENCES Trace.Trace (id_Trace)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace_Transfer ADD CONSTRAINT Transfer_LEvent_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.LinkEvent (id_Event)
	ON DELETE CASCADE;

CREATE INDEX Trace.Containments_parent_epc_IDX on Trace.Containments (parent_epc);

CREATE INDEX Trace.Containments_child_epc_IDX on Trace.Containments (child_epc);

-- Report tables
ALTER TABLE TRACE.REPORT ADD CONSTRAINT ERRORREPORT_PK PRIMARY KEY (ID_REPORT);

-- ALTER TABLE TRACE.REPORT ADD CONSTRAINT FOREIGN KEY (ID_SRCOBJECT)
--    REFERENCES TRACE.REPORTINPUT (ID_SRCOBJECT) ON DELETE CASCADE
--    CONSTRAINT REPORT_SOURCEOBJECT_FK;

ALTER TABLE TRACE.REPORTEPC ADD CONSTRAINT REPORT_EPC_FK FOREIGN KEY (ID_REPORT)
    REFERENCES TRACE.REPORT (ID_REPORT) ON DELETE CASCADE;
