#!/bin/ksh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# 5724-O98 (C) COPYRIGHT International Business Machines Corp. 2006 - 2007
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# editServerConf.sh - updates the RFIDIC server configuration
# Usage: editServerConf.sh <mdm_cache_refresh_rate> <was_capture>
#            mdm_cache_refresh_rate - cache refresh rate value (seconds)
#
#
# This script is not meant to be run as a standalone script. 
# It is ONLY invoked from inside other deployment/configuration scripts. 
#
# Running this script as a standalone script is NOT supported.
#        
##################################################################################

#
# setup solution environment
#
binDir=`dirname ${0}`
if [ -f $binDir/pedigree-env.sh ]; then
	. $binDir/pedigree-env.sh
else
	echo "$0 : File not found ${binDir}/pedigree-env.sh"
	exit 1
fi


RM="rm -f"
TMP=/tmp/${RFIDIC_USER}
if [ -f ${TMP} ]; then
	${RM} ${TMP}
fi
if [ ! -d ${TMP} ]; then
	mkdir -p ${TMP}
fi


#
# Update text contents of the <MDMCacheRefreshRate> node (contains the MDM 
# cache refresh rate)
#
# $1 = MDM cache refresh rate value (seconds)
#
updateMDMCacheRefreshRate() 
{
updateDone=`grep '<MDMCacheRefreshRate>'$1'</MDMCacheRefreshRate>' ${RFIDIC_HOME}/etc/RFIDICServer.xml`
if [ ! -z "$updateDone" ]; then
	# MDM Cache refresh rate is already updated
	echo_message FEAT05001I "${0}"
else 
	# updating MDM Cache refresh rate"
	echo_message FEAT05002I "${0}" $1
	
	${RM} ${RFIDIC_HOME}/etc/RFIDICServer.xml.temp > /dev/null
	${CP} ${RFIDIC_HOME}/etc/RFIDICServer.xml ${TMP}/RFIDICServer.xml.bak
	sed 's#<MDMCacheRefreshRate>.*</MDMCacheRefreshRate>#<MDMCacheRefreshRate>'$1'</MDMCacheRefreshRate>#' \
      ${RFIDIC_HOME}/etc/RFIDICServer.xml > ${TMP}/RFIDICServer.xml.$$
	${CP} ${TMP}/RFIDICServer.xml.$$ ${RFIDIC_HOME}/etc/RFIDICServer.xml
	${RM} ${TMP}/RFIDICServer.xml.$$
fi
unset updateDone
}


#
# Insert the file indicated by parameter $1 to the MetaDataRepository 
# configuration if not already there.
#
# $1 = Metadata file name
#
updateMetaDataRepository() 
{
updateDone=`grep '<MetaDataFile>'$1'</MetaDataFile>' ${RFIDIC_HOME}/etc/RFIDICServer.xml`
if [ ! -z "$updateDone" ]; then
	# MetaData repository - TODO globalize messages
	echo "Metadata repository already updated for $1"
else 
	echo "Inserting $1 into metadata repository"
	
	${RM} ${RFIDIC_HOME}/etc/RFIDICServer.xml.temp > /dev/null
	${CP} ${RFIDIC_HOME}/etc/RFIDICServer.xml ${TMP}/RFIDICServer.xml.bak

	sed 's#<MetaDataFile>ProductMetaData.xml</MetaDataFile>#<MetaDataFile>ProductMetaData.xml</MetaDataFile>\
  	  <MetaDataFile>'$1'</MetaDataFile>#' ${RFIDIC_HOME}/etc/RFIDICServer.xml > ${TMP}/RFIDICServer.xml.$$
	${CP} ${TMP}/RFIDICServer.xml.$$ ${RFIDIC_HOME}/etc/RFIDICServer.xml
	${RM} ${TMP}/RFIDICServer.xml.$$
fi
unset updateDone
}

# ---------------------------------------------------------------------
# Main
#
# Parse command line - assign the following variables:
#  $1 = mdm_cache
#
if [ $# -ne 1 ]; then
    echo_message FEAT05004I "$0"
    exit 1
else
    mdm_cache=$1
fi

run_command updateMDMCacheRefreshRate $mdm_cache
run_command updateMetaDataRepository ContactMetaData.xml
run_command updateMetaDataRepository LicenseMetaData.xml
run_command updateMetaDataRepository PartnerMetaData.xml
run_command updateMetaDataRepository PartnerPrivateMetaData.xml
run_command updateMetaDataRepository LocationAlternateMetaData.xml

exit 0
