#!/bin/ksh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# (C) COPYRIGHT International Business Machines Corp. 2008, 2012
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#   inst-upgr-ped-env.sh: Sets the environment for the pedigree upgrade scripts to use
###############################################################################################################

sDir=`dirname ${0}`
scriptDir=`cd $sDir | pwd`

CP="/bin/cp"
RM="/bin/rm -f"
ECHO="echo"
AWK="awk -F ".""
AWK_EQUAL="awk -F "=""
AWK_BCK_SLSH="awk -F>"
AWK_COLON="awk -F ":""
AWK_BRACE1="awk -F "\>""
AWK_BRACE2="awk -F "\<""
RFIDIC_PROFILE=".profile"
HEAD="head -n"
TAIL="tail -n"
USERID="id"
ID=`id`
TRUE=0
FALSE=1

OS=`/bin/uname`
case $OS in
	AIX)
		HOSTNAME=`hostname -s`
		HOSTNAMEFULL=`hostname`	
		;;
	Linux)
		ECHO="echo -e"
		HOSTNAME=`hostname -s`
		RFIDIC_PROFILE=".bash_profile"
		HOSTNAMEFULL=`hostname -f`
		CP="/bin/cp --reply=yes"
		;;
	SunOS)
		AWK="awk -F."
		AWK_EQUAL="awk -F="
		AWK_BCK_SLSH="awk -F>"
		HOSTNAME=`hostname`
		release=`uname -r`
		if [ "$release" = "5.10" ];then
			HOSTNAMEFULL=`/usr/sbin/check-hostname | awk '{print($7)}'`
		else
			HOSTNAMEFULL=`/usr/lib/mail/sh/check-hostname | awk '{print($7)}'`
		fi
		AWK_COLON="awk -F:"
		AWK_BRACE1="awk -F>"
		AWK_BRACE2="awk -F<"
		HEAD="head -"
		TAIL="tail -"
		USERID="id -a"
		ID=`id -a`
		;;
esac
CURRENT_USER=`expr "$ID" : ".*uid=[0-9]*(\([^)]*\)*"`
CURRENT_GROUP=`expr "$ID" : ".*gid=[0-9]*(\([^)]*\)*"`

distributed(){
host=$1
if [ "$OS" = "AIX" ];then
	IP=`host -n -t A $HOSTNAME | awk '{print($4)}'`
elif [ "$OS" = "Linux" ];then
	IP=`hostname -i`
elif [ "$OS" = "SunOS" ];then
	IP=`getent hosts $HOSTNAME | awk '{print($1)}'`
fi
if [ "$host" = "$HOSTNAME" -o "$host" = "$HOSTNAMEFULL" -o "$host" = "$IP" ];then
	return 0
else 
	return 1
fi
}

run_command(){
        command="$*"
        "$@"
        retcode=$?
        if [ "$retcode" -ne 0 ]
        then
		  getMessage TSIN01013E $command 
		  echo_msg "$msg"
                #echo_msg "Error occured while running command: $command"
                exit $retcode
        fi
}

echo_msg(){
   if [ "$SILENT" = "Y" ];then
	$ECHO $1 >> $LOG
   else
   	$ECHO $1 | tee -a $LOG
   fi
}

runUserCommand()
{
        user=$1
        shift
        command="$*"
        retcode=1
        COUNT=0
	 getMessage TSIN01014I $user
	 echo_msg "$msg"
        #echo "If prompted - enter the password for $user"
        while [ $retcode -ne 0 ] && [ $COUNT -lt 2 ]
        do

                if [ "$OS" = "SunOS" ];then
                        /bin/su - ${user} -c "${command}"
                        retcode=$?
                elif [ "$OS" = "AIX" ];then
                        /bin/su - ${user} "-c ${command}"
                        retcode=$?
                else
                        /bin/su - -c "${command}" ${user}
                        retcode=$?
                fi
              COUNT=`expr $COUNT + 1`
        done
   		return $retcode
}

databackup(){
	$TS_HOME/bin/stopRFIDIC.sh $credentials
	#$ECHO "\n\n"

	if [ "$DB_TYPE" = "ORACLE" ];then
		$TS_HOME/bin/startRFIDIC.sh -components=oracle >> $LOG
		if [ -d "$PEDIGREE_HOME/bin/Ped_V25" ];then
			run_command rm -rf $PEDIGREE_HOME/bin/Ped_V25
		fi
		run_command mkdir $PEDIGREE_HOME/bin/Ped_V25
		run_command chown $TS_ADMIN_USER:$TS_ADMIN_GROUP $PEDIGREE_HOME/bin/Ped_V25
		run_command touch $PEDIGREE_HOME/bin/Ped_V25/dbexport.out
		run_command chmod 577 $PEDIGREE_HOME/bin/Ped_V25/dbexport.out	
		${DBMS_HOME}/bin/exp "$DBMS_ADMIN_USER"/"$DBMS_ADMIN_PWD"@$DBMS_DB_NAME file=${PEDIGREE_HOME}/bin/Ped_V25/dbexport.out full=yes >> $LOG
	
	elif [ "$DB_TYPE" = "DB2" ];then
		$TS_HOME/bin/startRFIDIC.sh -components=db2 >> $LOG
		${DBMS_HOME}/bin/db2move $DBMS_DB_NAME export -u ${DBMS_ADMIN_USER} -p ${DBMS_ADMIN_PWD} >> $LOG
	fi
			
	if [ "$?" -eq 0 ]; then
		rfidic-get-message.sh RFID05120I
	else
		rfidic-get-message.sh RFID05121E
		exit 1
	fi
	if [ -z "$was_runas_user" ];then
       	$TS_HOME/bin/startRFIDIC.sh -components=was,mq $credentials
	else
		$TS_HOME/bin/startRFIDIC.sh -components=was,mq $credentials $was_runas
	fi

}

displayLA(){
	if [ "$LICENSE_ACCEPT" = "Y" -o "$LICENSE_ACCEPT" = "y" ];then
		return;
	fi
	run_command cd $scriptDir
	getMessage TSIN01043I
	$ECHO "$msg"
	#$ECHO "Press the <<Enter>> key to read the License Agreement"
	read discard
	if [ "$OS" = "Linux" -o "$OS" = "SunOS" ];then
		run_command more -c -d -25 /tmp/pedExtract/ts/licenses/epedigree/LA_en.txt
		run_command more -c -d -25 /tmp/pedExtract/ts/licenses/epedigree/LI_en.txt
	elif [ "$OS" = "AIX" ];then
		run_command more -c -d -n 25 /tmp/pedExtract/ts/licenses/epedigree/LA_en.txt
		run_command more -c -d -n 25 /tmp/pedExtract/ts/licenses/epedigree/LI_en.txt    
	fi

	while [ 1 ];do
		$ECHO "-------------------------------------------------------------"
		getMessage TSIN01044I
		$ECHO "$msg"
		#$ECHO "Enter 'A' to accept the license agreement or 'R' to reject it"
		$ECHO "-------------------------------------------------------------"
		read input
		if [ "$input" = "A" -o "$input" = "a" ];then
			return;
		elif [ "$input" = "R" -o "$input" = "r" ];then
			exit 1;
		fi
	done
}

asciiUpdate(){
	# Takes an array of search and replace strings for a file, constructs the sed script and performs the update on the file
        index=0
        searchStr=$2
        replaceStr=$3
        count=${#searchStr[*]}
        command="{\n"
        while [ "$index" -lt "$count" ]
        do
                command=$command"s%"${searchStr[$index]}"%"${replaceStr[$index]}"%g\n"
                index=`expr $index + 1`
        done
        command=$command"}"
        $ECHO "$command" > $1.sed
       	run_command sed -f $1.sed $1 > $1.tmp
	run_command mv -f $1.tmp $1
	run_command rm -f $1.sed
}

promptDBAUser(){
	if [ -z "$dba_user" ];then
		getMessage TSIN01017I
	    	echo_msg "\n$msg"
		#echo_msg "\nEnter the dba user for the database: "
		read dba_user
	fi
	if [ -n "$dba_user" -a -z "$dba_password" ];then
		getMessage TSIN01018I $dba_user 
	    	echo_msg "\n$msg"
		#echo_msg "\nEnter the password for the user $dba_user : "
		stty -echo
		read dba_password
		stty echo
	fi
}

doPedFilesExist()
{

   pedEnvExists=`unzip -l $PEDIGREE_BUILD_PATH | grep epedigree/bin/pedigree-env.sh`

   pedXmlExists=`unzip -l $PEDIGREE_BUILD_PATH | grep epedigree/etc/pedigree.xml`


}


updateBinaries(){
	versionTo=$1
	# Extract the files from the build
	run_command cp ${PEDIGREE_BUILD_PATH} ${PEDIGREE_HOME}/epedigree.zip 
	run_command cd ${PEDIGREE_HOME}
	run_command tar -xf epedigree.tar >> $LOG

	cp -rf $PEDIGREE_HOME/epedigree/bin/* $PEDIGREE_HOME/bin

	mv -f $PEDIGREE_HOME/epedigree/lib/* $PEDIGREE_HOME/lib
	mv -f $PEDIGREE_HOME/epedigree/etc/* $PEDIGREE_HOME/etc
 	mv -f $PEDIGREE_HOME/epedigree/licenses/* $PEDIGREE_HOME/licenses
	cp -rf $PEDIGREE_HOME/epedigree/sample/* $PEDIGREE_HOME/sample
	
	rm -rf $PEDIGREE_HOME/epedigree
	${RM} epedigree.tar

	#For future (Delta) versions, interogate the tar file,
	#if pedigree-env.sh file exist in .tar file then perform the ascii-update 
	#or else use the content in the old pedigree-env.sh (no ascii-update)
	 
	doPedFilesExist

	if [ "$pedEnvExists" != "" ];then
		echo "updating pedigree-env.sh"
		updatePedEnv
	fi

	if [ "$pedXmlExists" != "" ];then
		echo "updating pedigree.xml"
		updatePedXML
	fi
	
	# Updating pedigree version properties file under ${TS_HOME}/features/pedigree
	cp -rf ${PEDIGREE_HOME}/etc/version.properties ${TS_HOME}/features/pedigree/
	getMessage TSIN02037I
	echo_msg "\n\n$msg"
	#echo_msg "\n\n----------Updating Binaries - Done------"
}

updatePedEnv() {

	########## Updating the pedigree-env.sh ################
	searchStr[0]='RFIDIC_SOLDIR=${RFIDIC_HOME}/features/pedigree'
	searchStr[1]='RFIDIC_HOME=${RFIDIC_SOLDIR}'
	searchStr[2]='CAPTURE_TYPE=HTTP'
	searchStr[3]='MQ_HOME=/opt/mqm'
	searchStr[4]='MQ_LSR_PORT=1414'
	searchStr[5]='MQ_USER=${RFIDIC_USER}'
	searchStr[6]='DB_TYPE=INFORMIX'
	searchStr[7]='DBMS_HOME=/opt/IBM/informix'
	searchStr[8]='DBMS_ADMIN_USER=tsadmin'
	searchStr[9]='DBMS_ADMIN_PWD=tsadmin123'
	searchStr[10]='WAS_HOME=/opt/IBM/WebSphere/AppServer'
	searchStr[11]='NODENAME=$NODENAME'
	searchStr[12]='CELLNAME="$HOSTNAME"Node01Cell'
	searchStr[13]='PROFILENAME=AppSrv01'
	searchStr[14]='QUEUE_MANAGER=TS.QUEUE.MANAGER'
	searchStr[15]='SERVERNAME=server1'
	searchStr[16]='RFIDIC_HOST=$HOSTNAMEFULL'
	searchStr[17]='DBMS_DB_NAME=pedigree'
	searchStr[18]='DOC_CAPTURE_BUS_NAME=DocPedigreeCaptureBus'
	searchStr[19]='DOC_SERVICE_BUS_NAME=DocPedigreeServiceBus'
	searchStr[20]='MQ_USER_PASSWORD=${rfidic_user_password}'
	searchStr[21]='PEDIGREE_DB_HOST=${HOSTNAMEFULL}'
	searchStr[22]='RFIDIC_DB_HOST=${HOSTNAMEFULL}'
	searchStr[23]='PEDIGREE_MQ_HOST=${HOSTNAMEFULL}'
	searchStr[24]='RFIDIC_PORT=9080'
	searchStr[25]='PED_DBMS_LIB_HOME=$DBMS_HOME/jdbc/lib'
	
	searchStr[26]='DOCPEDIGREE_QUEUE=DOCUMENTQUEUE'
	searchStr[27]='QNAME_PEDIGREE_EVENT=PedigreeEventIn'
	searchStr[28]='MDM_CHANGE_NOTIF_QUEUE_NAME=MDMChangeNotification'
	if [ "$install" = "true" ];then
    		replaceStr[0]="RFIDIC_SOLDIR=$PEDIGREE_HOME"
	else
		replaceStr[0]="RFIDIC_SOLDIR=$RFIDIC_SOLDIR"
	fi
	replaceStr[1]="RFIDIC_HOME=$TS_HOME"
	replaceStr[2]="CAPTURE_TYPE=$CAPTURE_TYPE"
	replaceStr[3]="MQ_HOME=$MQ_HOME"
	replaceStr[4]="MQ_LSR_PORT=$MQ_LSR_PORT"
	replaceStr[5]="MQ_USER=$MQ_USER"
	replaceStr[6]="DB_TYPE=$DB_TYPE"
	replaceStr[7]="DBMS_HOME=$DBMS_HOME"		
	replaceStr[8]="DBMS_ADMIN_USER=$DBMS_ADMIN_USER"
	replaceStr[9]="DBMS_ADMIN_PWD=$DBMS_ADMIN_PWD"
 	replaceStr[10]="WAS_HOME=$WAS_HOME"
	replaceStr[11]="NODENAME=$NODENAME"
	replaceStr[12]="CELLNAME=$CELLNAME"
	if [ "$install" = "true" ];then
		replaceStr[13]="PROFILENAME=$WAS_PROFILE"
		replaceStr[14]="QUEUE_MANAGER=$MQ_QUEUE_MANAGER"
	else
		replaceStr[13]="PROFILENAME=$PROFILENAME"
		replaceStr[14]="QUEUE_MANAGER=$QUEUE_MANAGER"
	fi
	replaceStr[15]="SERVERNAME=$SERVERNAME"
	replaceStr[16]="RFIDIC_HOST=$TS_HOST"
	if [ "$install" = "true" ];then
		replaceStr[17]="DBMS_DB_NAME=$DB_NAME"
		replaceStr[18]="DOC_CAPTURE_BUS_NAME=$Document_capture_bus"
		replaceStr[19]="DOC_SERVICE_BUS_NAME=$Document_service_bus"
	else
		replaceStr[17]="DBMS_DB_NAME=$DBMS_DB_NAME"
		replaceStr[18]="DOC_CAPTURE_BUS_NAME=$DOC_CAPTURE_BUS_NAME"
		replaceStr[19]="DOC_SERVICE_BUS_NAME=$DOC_SERVICE_BUS_NAME"
	fi
	replaceStr[20]="MQ_USER_PASSWORD=$MQ_USER_PASSWORD"
	replaceStr[21]="PEDIGREE_DB_HOST=$PEDIGREE_DB_HOST"
	replaceStr[22]="RFIDIC_DB_HOST=$TS_DB_HOST"
	replaceStr[23]="PEDIGREE_MQ_HOST=$PEDIGREE_MQ_HOST"
	if [ "$install" = "true" ];then
		replaceStr[24]="RFIDIC_PORT=$TS_APP_PORT"
		replaceStr[25]="PED_DBMS_LIB_HOME=$DBMS_JDBC_LIB_PATH"
	else
		replaceStr[24]="RFIDIC_PORT=$RFIDIC_PORT"
		replaceStr[25]="PED_DBMS_LIB_HOME=$PED_DBMS_LIB_HOME"
	fi
	replaceStr[26]="DOCPEDIGREE_QUEUE=$DOCPEDIGREE_QUEUE"
	replaceStr[27]="QNAME_PEDIGREE_EVENT=$QNAME_PEDIGREE_EVENT"
	replaceStr[28]="MDM_CHANGE_NOTIF_QUEUE_NAME=$MDM_CHANGE_NOTIF_QUEUE_NAME"

	asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" $searchStr $replaceStr

	asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" 'RFIDIC_USER=tsadmin' "RFIDIC_USER=$TS_ADMIN_USER"
	asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" 'rfidic_user_password=tsadmin123' "rfidic_user_password=$rfidic_user_password"
	if [ "$install" = "true" ];then
		echo " "
	else
		if [ -f ${PEDIGREE_HOME}/etc/fop.xconf ];then
		run_command mv -f ${PEDIGREE_HOME}/etc/fop.xconf ${TS_HOME}/features/pedigree
		fi							
	fi
		
	if [ "$DB_TYPE" = "ORACLE" ];then
		searchStr[0]='ORACLE_GROUP=system'
		searchStr[1]='ORACLE_USER=oracle'
		searchStr[2]='DBMS_PORT=1526'
		if [ "$install" = "true" ];then
			echo " "
		else
			searchStr[3]='ORACLE_JDBC_URL=jdbc:oracle:thin:@${HOSTNAMEFULL}:${DBMS_PORT}:${DBMS_DB_NAME}'
		fi
		
		replaceStr[0]="ORACLE_GROUP=$ORACLE_GROUP"
		replaceStr[1]="ORACLE_USER=$ORACLE_USER"
		if [ "$install" = "true" ];then
			replaceStr[2]="DBMS_PORT=$ORACLE_PORT_NUMBER"
		else
			replaceStr[2]="DBMS_PORT=$DBMS_PORT"
			replaceStr[3]="ORACLE_JDBC_URL=$ORACLE_JDBC_URL"
		fi
		asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" $searchStr $replaceStr

		DRIVER_CLASS="oracle.jdbc.OracleDriver"		
		if [ "$install" = "true" ];then
			if [ -n "$DB_URL" ];then
				JDBC_URL="$DB_URL"
				searchStr[0]='jdbc:oracle:thin:@${PEDIGREE_DB_HOST}:${DBMS_PORT}:${DBMS_DB_NAME}'
				replaceStr[0]="$DB_URL"
				asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" $searchStr $replaceStr
			else
				JDBC_URL="jdbc:oracle:thin:@${PEDIGREE_DB_HOST}:${ORACLE_PORT_NUMBER}:${DB_NAME}"
			fi
		else
				JDBC_URL="jdbc:oracle:thin:@${PEDIGREE_DB_HOST}:${DBMS_PORT}:${DBMS_DB_NAME}"
		fi
	elif [ "$DB_TYPE" = "DB2" ];then
		if [ "$install" = "true" ];then
			searchStr[0]='DB2_INSTANCE=db2inst1'
			searchStr[1]='DBMS_PORT=1526'
			searchStr[2]='DB2_SERVER=$IP'
			
			replaceStr[0]="DB2_INSTANCE=$DB2_INSTANCE"
			replaceStr[1]="DBMS_PORT=$DB2_PORT_NUMBER"
			replaceStr[2]="DB2_SERVER=$PEDIGREE_DB_HOST"		
			asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" $searchStr $replaceStr
			DRIVER_CLASS="com.ibm.db2.jcc.DB2Driver"
			JDBC_URL="jdbc:db2://${PEDIGREE_DB_HOST}:${DB2_PORT_NUMBER}/${DB_NAME}"
		else		
			searchStr[0]='DB2_GROUP=db2grp1'
			searchStr[1]='DB2_INSTANCE=db2inst1'
			searchStr[2]='DBMS_PORT=1526'
			searchStr[3]='DB2_SERVER=$IP'
	
			replaceStr[0]="DB2_GROUP=$DB2_GROUP"
			replaceStr[1]="DB2_INSTANCE=$DB2_INSTANCE"
			replaceStr[2]="DBMS_PORT=$DBMS_PORT"		
			replaceStr[3]="DB2_SERVER=$PEDIGREE_DB_HOST"		
			asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" $searchStr $replaceStr
			DRIVER_CLASS="com.ibm.db2.jcc.DB2Driver"
			JDBC_URL="jdbc:db2://${PEDIGREE_DB_HOST}:${DBMS_PORT}/${DBMS_DB_NAME}"
		fi		
	else
		getMessage TSIN01100E
		echo_msg "\n$msg"
		#echo_msg "Invalid DB type specified"
		exit_install
	fi
	
	# If it is secure WAS, then replace the dummy values for securing internal web services
	# with the actual values set in the property file setPedigreeEnv.sh
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
		searchStr[0]='WS_USER_1=$WS_USER_1'
		searchStr[1]='WS_PWD_1=$WS_PWD_1'
		searchStr[2]='WS_SSL_1=$WS_SSL_1'
		searchStr[3]='WS_USER_2=$WS_USER_2'
		searchStr[4]='WS_PWD_2=$WS_PWD_2'
		searchStr[5]='WS_SSL_2=$WS_SSL_2'
		searchStr[6]='WS_USER_3=$WS_USER_3'
		searchStr[7]='WS_PWD_3=$WS_PWD_3'
		searchStr[8]='WS_SSL_3=$WS_SSL_3'
		searchStr[9]='WS_USER_4=$WS_USER_4'
		searchStr[10]='WS_PWD_4=$WS_PWD_4'
		searchStr[11]='WS_SSL_4=$WS_SSL_4'
		searchStr[12]='WS_USER_5=$WS_USER_5'
		searchStr[13]='WS_PWD_5=$WS_PWD_5'
		searchStr[14]='WS_SSL_5=$WS_SSL_5'
	
		replaceStr[0]="WS_USER_1=$WS_USER_1"
		replaceStr[1]="WS_PWD_1=$WS_PWD_1"
		replaceStr[2]="WS_SSL_1=$WS_SSL_1"
		replaceStr[3]="WS_USER_2=$WS_USER_2"
		replaceStr[4]="WS_PWD_2=$WS_PWD_2"
		replaceStr[5]="WS_SSL_2=$WS_SSL_2"
		replaceStr[6]="WS_USER_3=$WS_USER_3"
		replaceStr[7]="WS_PWD_3=$WS_PWD_3"
		replaceStr[8]="WS_SSL_3=$WS_SSL_3"
		replaceStr[9]="WS_USER_4=$WS_USER_4"
		replaceStr[10]="WS_PWD_4=$WS_PWD_4"
		replaceStr[11]="WS_SSL_4=$WS_SSL_4"
		replaceStr[12]="WS_USER_5=$WS_USER_5"
		replaceStr[13]="WS_PWD_5=$WS_PWD_5"
		replaceStr[14]="WS_SSL_5=$WS_SSL_5"

		asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" $searchStr $replaceStr
	fi
	########## End of Updating the pedigree-env.sh ################
}

updatePedXML(){
	##### Updating the pedigree.xml and sample pedigree.xml ################
	# Update DB properties in pedigree.xml
	searchStr[0]='property name="sqlFlavor" value="informix"/'
	searchStr[1]='property name="driverClassName" value="com.informix.jdbc.IfxDriver"/'
	searchStr[2]='value="jdbc:informix-sqli://localhost:1526/pedigree:INFORMIXSERVER=IBMIFX_DSv11"/'
	searchStr[3]='property name="user" value="rfidic"/'
	searchStr[4]='property name="password" value="$password"/'

	`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"sqlFlavor" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}' 1>&2 > /tmp/TSTemp.txt`
	OLD_DB_TYPE=`head -1 /tmp/TSTemp.txt`
	OLD_DRIVER_CLASS=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"driverClassName" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_JDBC_URL=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"databaseUrl" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"user" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}' 1>&2 > /tmp/TSTemp.txt`
	OLD_DBMS_ADMIN_USER=`tail -1 /tmp/TSTemp.txt`
	`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"password" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}' 1>&2 > /tmp/TSTemp.txt`
	OLD_DBMS_ADMIN_PWD=`tail -1 /tmp/TSTemp.txt`
		
	if [ -z "$OLD_DB_TYPE" ];then
		OLD_DB_TYPE='"informix"/'
	fi
	if [ -z "$OLD_DBMS_ADMIN_USER" ];then
		OLD_DBMS_ADMIN_USER='"rfidic"/'
	fi
	if [ -z "$OLD_DBMS_ADMIN_PWD" ];then
		OLD_DBMS_ADMIN_PWD='"password"/'
	fi
		
	echo "OLD DB TYPE:$OLD_DB_TYPE NEW DB TYPE :$DB_TYPE"  >> $LOG
	echo "OLD DRIVER CLASS:$OLD_DRIVER_CLASS NEW DRIVER CLASS:$DRIVER_CLASS"  >> $LOG
	echo "OLD JDBC URL:$OLD_JDBC_URL NEW JDBC URL:$JDBC_URL"  >> $LOG
	echo "OLD DBMS ADMN USER:$OLD_DBMS_ADMIN_USER NEW DBMS ADMN USER:$DBMS_ADMIN_USER"  >> $LOG
	echo "OLD DBMS ADMN PWD:$OLD_DBMS_ADMIN_PWD NEW DBMS ADMN PWD:$DBMS_ADMIN_PWD" >> $LOG
		
	replaceStr[0]="property name=\"sqlFlavor\" value=$OLD_DB_TYPE"
	replaceStr[1]="property name=\"driverClassName\" value=$OLD_DRIVER_CLASS"
	replaceStr[2]="value=\"$JDBC_URL\"/"
	replaceStr[3]="property name=\"user\" value=$OLD_DBMS_ADMIN_USER"
	replaceStr[4]="property name=\"password\" value=$OLD_DBMS_ADMIN_PWD"

	asciiUpdate "$PEDIGREE_HOME/etc/pedigree.xml" "$searchStr" "$replaceStr"

	### Now lets do sample/etc/pedigree.xml

	searchStr[0]='property name="sqlFlavor" value="informix"/'
	searchStr[1]='property name="driverClassName" value="com.informix.jdbc.IfxDriver"/'
	searchStr[2]='value="jdbc:informix-sqli://localhost:1526/pedigree:INFORMIXSERVER=IBMIFX_DSv11"/'
	searchStr[3]='property name="user" value="rfidic"/'
	searchStr[4]='property name="password" value="$password"/'

	replaceStr[0]="property name=\"sqlFlavor\" value=$OLD_DB_TYPE"
	replaceStr[1]="property name=\"driverClassName\" value=$OLD_DRIVER_CLASS"
	replaceStr[2]="value=\"$JDBC_URL\"/"
	replaceStr[3]="property name=\"user\" value=$OLD_DBMS_ADMIN_USER"
	replaceStr[4]="property name=\"password\" value=$OLD_DBMS_ADMIN_PWD"

	asciiUpdate "$PEDIGREE_HOME/sample/etc/pedigree.xml" "$searchStr" "$replaceStr"

	# Update TS hostname and port info
	asciiUpdate "$PEDIGREE_HOME/etc/pedigree.xml" 'http://localhost:9080' "http://${TS_HOST}:${RFIDIC_PORT}"
	asciiUpdate "$PEDIGREE_HOME/sample/etc/pedigree.xml" 'http://localhost:9080' "http://${TS_HOST}:${RFIDIC_PORT}"

	# Update TS hostname, port number and user info for secured TS
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
       	        searchStr[0]='https://localhost:9043/'
		searchStr[1]='property name="userid" value="rfidic"'
		searchStr[2]='property name="password" value="rfidic"'

		replaceStr[0]="https://${TS_HOST}:${RFIDIC_PORT}"
		replaceStr[1]="property name=\"userid\" value=\"${was_admin_user}\""
		replaceStr[2]="property name=\"password\" value=\"${was_admin_password}\""

		asciiUpdate "$PEDIGREE_HOME/etc/pedigree.xml" "$searchStr" "$replaceStr"

       	        searchStr[0]='https://localhost:9080/'
		searchStr[1]='property name="userid" value="rfidic"'
		searchStr[2]='property name="password" value="rfidic"'

		replaceStr[0]="https://${TS_HOST}:${RFIDIC_PORT}/com.ibm.rfidic.web"
		replaceStr[1]="property name=\"userid\" value=\"${was_admin_user}\""
		replaceStr[2]="property name=\"password\" value=\"${was_admin_password}\""

		asciiUpdate "$PEDIGREE_HOME/sample/etc/pedigree.xml" "$searchStr" "$replaceStr"
	fi 

	# Update MQ information & PEDIGREE_HOME value 
	searchStr[0]='property name="QUEUE_MANAGER_NAME" value="RFIDICv11.QUEUE.MANAGER"/'
	searchStr[1]='property name="QUEUE_NAME" value="EPCEVENT"/'
	searchStr[2]='property name="HOST_NAME" value="MQSYSTEMNAME"/'
	searchStr[3]='property name="MQ_LISTENER_PORT"><value type="int">1414'

	OLD_QUEUE_MANAGER_NAME=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"QUEUE_MANAGER_NAME" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_QUEUE_NAME=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"QUEUE_NAME" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_HOST_NAME=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"HOST_NAME" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_LISTENER_PORT=`cat $TS_HOME/features/pedigree/pedigree.xml | grep 'property name="MQ_LISTENER_PORT' | ${AWK_BRACE1} '{print($3)}' | ${AWK_BRACE2} '{print($1)}'`

	echo "OLD Q MGR:$OLD_QUEUE_MANAGER_NAME NEW Q MGR:$QUEUE_MANAGER" >> $LOG
	echo "OLD Q NAME:$OLD_QUEUE_NAME NEW Q NAME:$QUEUE_NAME" >> $LOG
	echo "OLD HOST NAME:$OLD_HOST_NAME NEW HOST NAME:$PEDIGREE_MQ_HOST" >> $LOG
	echo "OLD LISTENER PORT:$OLD_LISTENER_PORT NEW LISTENER PORT :$MQ_LSR_PORT" >> $LOG

	replaceStr[0]="property name=\"QUEUE_MANAGER_NAME\" value=$OLD_QUEUE_MANAGER_NAME"
	replaceStr[1]="property name=\"QUEUE_NAME\" value=$OLD_QUEUE_NAME"
	replaceStr[2]="property name=\"HOST_NAME\" value=$OLD_HOST_NAME"
	replaceStr[3]="property name=\"MQ_LISTENER_PORT\"><value type=\"int\">$OLD_LISTENER_PORT"

	asciiUpdate "$PEDIGREE_HOME/etc/pedigree.xml" "$searchStr" "$replaceStr"

	searchStr[0]='property name="QUEUE_MANAGER_NAME" value="RFIDICv11.QUEUE.MANAGER"/'
	searchStr[1]='property name="QUEUE_NAME" value="EPCEVENT"/'
	searchStr[2]='property name="HOST_NAME" value="MQSYSTEMNAME"/'
	searchStr[3]='property name="MQ_LISTENER_PORT"><value type="int">1414'

	replaceStr[0]="property name=\"QUEUE_MANAGER_NAME\" value=$OLD_QUEUE_MANAGER_NAME"
	replaceStr[1]="property name=\"QUEUE_NAME\" value=$OLD_QUEUE_NAME"
	replaceStr[2]="property name=\"HOST_NAME\" value=$OLD_HOST_NAME"
	replaceStr[3]="property name=\"MQ_LISTENER_PORT\"><value type=\"int\">$OLD_LISTENER_PORT"
		
	asciiUpdate "$PEDIGREE_HOME/sample/etc/pedigree.xml" "$searchStr" "$replaceStr"
		
	# Update Keystore values in etc/pedigree.xml
	searchStr[0]='property name="KS_FILE_PATH" value="${ks_path}"/'
	searchStr[1]='property name="KS_STORE_PASSWD" value="${ks_store_passwd}"/'
	searchStr[2]='property name="KS_KEY_PASSWD" value="${ks_key_passwd}"/'
	searchStr[3]='property name="TRUSTSTORE_FILE_PATH" value="${ts_path}"/'
	searchStr[4]='property name="TS_STORE_PASSWD" value="${ts_store_passwd}"/'
	searchStr[5]='property name="KEYSTORE_TYPE" value="${ks_type}"/'
	searchStr[6]='property name="REPOSITORY_BACKUP_DIR" value="${repository_backup_dir}"/'
	searchStr[7]='property name="FAILED_DOCUMENT_DIR" value=""/'
	searchStr[8]='property name="localLocationId" value="${local_location}"/'
	
	OLD_KS_FILE_PATH=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"KS_FILE_PATH" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_KS_STORE_PASSWD=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"KS_STORE_PASSWD" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_KS_KEY_PASSWD=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"KS_KEY_PASSWD" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_TRUSTSTORE_FILE_PATH=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"TRUSTSTORE_FILE_PATH" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_TS_STORE_PASSWD=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"TS_STORE_PASSWD" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_KEYSTORE_TYPE=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"KEYSTORE_TYPE" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_REPOSITORY_BACKUP_DIR=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"REPOSITORY_BACKUP_DIR" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_FAILED_DOCUMENT_DIR=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"FAILED_DOCUMENT_DIR" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_LOCAL_LOCATION_ID=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "property name=\"localLocationId" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	
	echo "OLD_KS_FILE_PATH:$OLD_KS_FILE_PATH" >> $LOG
	echo "OLD_KS_STORE_PASSWD:$OLD_KS_STORE_PASSWD" >> $LOG
	echo "OLD_KS_KEY_PASSWD:$OLD_KS_KEY_PASSWD" >> $LOG
	echo "OLD_TRUSTSTORE_FILE_PATH:$OLD_TRUSTSTORE_FILE_PATH" >> $LOG
	echo "OLD_TS_STORE_PASSWD:$OLD_TS_STORE_PASSWD" >> $LOG
	echo "OLD_KEYSTORE_TYPE:$OLD_KEYSTORE_TYPE" >> $LOG
	echo "OLD_REPOSITORY_BACKUP_DIR:$OLD_REPOSITORY_BACKUP_DIR" >> $LOG
	echo "OLD_FAILED_DOCUMENT_DIR:$OLD_FAILED_DOCUMENT_DIR" >> $LOG
	echo "OLD_LOCAL_LOCATION_ID:$OLD_LOCAL_LOCATION_ID" >> $LOG

	replaceStr[0]="property name=\"KS_FILE_PATH\" value=$OLD_KS_FILE_PATH"
	replaceStr[1]="property name=\"KS_STORE_PASSWD\" value=$OLD_KS_STORE_PASSWD"
	replaceStr[2]="property name=\"KS_KEY_PASSWD\" value=$OLD_KS_KEY_PASSWD"
	replaceStr[3]="property name=\"TRUSTSTORE_FILE_PATH\" value=$OLD_TRUSTSTORE_FILE_PATH"
	replaceStr[4]="property name=\"TS_STORE_PASSWD\" value=$OLD_TS_STORE_PASSWD"
	replaceStr[5]="property name=\"KEYSTORE_TYPE\" value=$OLD_KEYSTORE_TYPE"
	replaceStr[6]="property name=\"REPOSITORY_BACKUP_DIR\" value=$OLD_REPOSITORY_BACKUP_DIR"
	replaceStr[7]="property name=\"FAILED_DOCUMENT_DIR\" value=$OLD_FAILED_DOCUMENT_DIR"
	replaceStr[8]="property name=\"localLocationId\" value=$OLD_LOCAL_LOCATION_ID"

	asciiUpdate "$PEDIGREE_HOME/etc/pedigree.xml" "$searchStr" "$replaceStr"

	# Update Keystore values in sample/etc/pedigree.xml
	searchStr[0]='property name="KS_FILE_PATH" value="/opt/ibm/InfoSphere/EPedigree/sample/cert/sample_security.jks"/'
	searchStr[1]='property name="KS_STORE_PASSWD" value=storerfidic123"/'
	searchStr[2]='property name="KS_KEY_PASSWD" value="keyrfidic123"/'
	searchStr[3]='property name="TRUSTSTORE_FILE_PATH" value="/opt/ibm/InfoSphere/EPedigree/sample/cert/sample_security.jks"/'
	searchStr[4]='property name="TS_STORE_PASSWD" value="storerfidic123"/'
	searchStr[5]='property name="KEYSTORE_TYPE" value="JKS"/'
	searchStr[6]='property name="REPOSITORY_BACKUP_DIR" value="${repository_backup_dir}"/'
	searchStr[7]='property name="FAILED_DOCUMENT_DIR" value=""/'

	# Get values for sample/pedigree.xml
	NEW_SAMPLE_KS_FILE_PATH='"\"$PEDIGREE_HOME/samples/epedigree/cert/sample_security.jks\"/"'
	OLD_SAMPLE_KS_STORE_PASSWD=`cat $PEDIGREE_HOME/sample/etc/pedigree.xml | grep "property name=\"KS_STORE_PASSWD" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_SAMPLE_KS_KEY_PASSWD=`cat $PEDIGREE_HOME/sample/etc/pedigree.xml | grep "property name=\"KS_KEY_PASSWD" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	NEW_SAMPLE_TRUSTSTORE_FILE_PATH="\"$PEDIGREE_HOME/samples/epedigree/cert/sample_security.jks\"/"
	OLD_SAMPLE_TS_STORE_PASSWD=`cat $PEDIGREE_HOME/sample/etc/pedigree.xml | grep "property name=\"TS_STORE_PASSWD" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`
	OLD_SAMPLE_KEYSTORE_TYPE=`cat $PEDIGREE_HOME/sample/etc/pedigree.xml | grep "property name=\"KEYSTORE_TYPE" | ${AWK_EQUAL} '{print($3)}' | ${AWK_BCK_SLSH} '{print($1)}'`

	echo "NEW_KS_SAMPLE_FILE_PATH:$NEW_SAMPLE_KS_FILE_PATH" >> $LOG
	echo "OLD_KS_SAMPLE_STORE_PASSWD:$OLD_SAMPLE_KS_STORE_PASSWD" >> $LOG
	echo "OLD_KS_SAMPLE_KEY_PASSWD:$OLD_SAMPLE_KS_KEY_PASSWD" >> $LOG
	echo "NEW_SAMPLE_TRUSTSTORE_FILE_PATH:$NEW_SAMPLE_TRUSTSTORE_FILE_PATH" >> $LOG
	echo "OLD_SAMPLE_TS_STORE_PASSWD:$OLD_SAMPLE_TS_STORE_PASSWD" >> $LOG
	echo "OLD_SAMPLE_KEYSTORE_TYPE:$OLD_SAMPLE_KEYSTORE_TYPE" >> $LOG
	echo "OLD_REPOSITORY_BACKUP_DIR:$OLD_REPOSITORY_BACKUP_DIR" >> $LOG
	echo "OLD_FAILED_DOCUMENT_DIR:$OLD_FAILED_DOCUMENT_DIR" >> $LOG

	replaceStr[0]="property name=\"KS_FILE_PATH\" value=$NEW_SAMPLE_KS_FILE_PATH"
	replaceStr[1]="property name=\"KS_STORE_PASSWD\" value=$OLD_SAMPLE_KS_STORE_PASSWD"
	replaceStr[2]="property name=\"KS_KEY_PASSWD\" value=$OLD_SAMPLE_KS_KEY_PASSWD"
	replaceStr[3]="property name=\"TRUSTSTORE_FILE_PATH\" value=$NEW_SAMPLE_TRUSTSTORE_FILE_PATH"
	replaceStr[4]="property name=\"TS_STORE_PASSWD\" value=$OLD_SAMPLE_TS_STORE_PASSWD"
	replaceStr[5]="property name=\"KEYSTORE_TYPE\" value=$OLD_SAMPLE_KEYSTORE_TYPE"
	replaceStr[6]="property name=\"REPOSITORY_BACKUP_DIR\" value=$OLD_REPOSITORY_BACKUP_DIR"
	replaceStr[7]="property name=\"FAILED_DOCUMENT_DIR\" value=$OLD_FAILED_DOCUMENT_DIR"

	asciiUpdate "$PEDIGREE_HOME/sample/etc/pedigree.xml" "$searchStr" "$replaceStr"
	#run_command cp -f ${PEDIGREE_HOME}/etc/pedigree.xml ${TS_HOME}/features/pedigree
	
	
	###updating pedigree.xml with hintProcessor if it exist in the earlier version
	
	QUERY=`cat ${TS_HOME}/features/pedigree/pedigree.xml | grep -n 'hintProcessor' | head -1 | ${AWK_COLON} '{print($1)}'`
	if [ "$QUERY" = "" ];then
		#$ECHO "Earlier version did not have help processor, copy the file to features directory and update it"
		run_command cp -f ${PEDIGREE_HOME}/etc/pedigree.xml ${TS_HOME}/features/pedigree
	else
		$ECHO "Adding hintProcessor"
	
		if [ -f ${PEDIGREE_HOME}/etc/pedigree.xml.temp ];then
			run_command rm -rf ${PEDIGREE_HOME}/etc/pedigree.xml.temp
		fi

		FIRST=`cat ${PEDIGREE_HOME}/etc/pedigree.xml | grep -n '</loadable>' | head -1 | ${AWK_COLON} '{print($1)}'`
		SECOND=`cat ${PEDIGREE_HOME}/etc/pedigree.xml | grep -n 'managedPersistence' | head -1 | ${AWK_COLON} '{print($1)}'`
		THIRD=`cat ${PEDIGREE_HOME}/etc/pedigree.xml | grep -n 'jdbcPersistence' | head -1 | ${AWK_COLON} '{print($1)}'`

		`cat ${PEDIGREE_HOME}/etc/pedigree.xml | head -$FIRST > ${PEDIGREE_HOME}/etc/pedigree.xml.temp`
		$ECHO "" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
		$ECHO "	<!--" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
       	$ECHO "		Oracle optimizer hints processor." >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
    	$ECHO "	-->" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
    	$ECHO "	<loadable id=\"hintProcessor\" class=\"com.ibm.rfidic.pharma.persistence.HintProcessor\">" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
		$ECHO "		<property name=\"enable\"><value type=\"boolean\">true</value></property>" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
		$ECHO "		<property name=\"hintsFile\"><value type=\"url\">hints.properties</value></property>" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
    	$ECHO "	</loadable>" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
		let FIRST=FIRST+1
		`cat ${PEDIGREE_HOME}/etc/pedigree.xml | sed -n ''$FIRST','$SECOND'p' >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp`
		$ECHO "	<property name=\"hintProcessor\"><value type=\"ref\">hintProcessor</value></property>" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
		let SECOND=SECOND+1
		`cat ${PEDIGREE_HOME}/etc/pedigree.xml | sed -n ''$SECOND','$THIRD'p' >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp`
		$ECHO "	<property name=\"hintProcessor\"><value type=\"ref\">hintProcessor</value></property>" >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp
		let THIRD=THIRD+1
		`cat ${PEDIGREE_HOME}/etc/pedigree.xml | sed -n ''$THIRD',$p' >> ${PEDIGREE_HOME}/etc/pedigree.xml.temp`

		run_command cp -f ${PEDIGREE_HOME}/etc/pedigree.xml.temp ${PEDIGREE_HOME}/etc/pedigree.xml
		run_command cp -f ${PEDIGREE_HOME}/etc/pedigree.xml ${TS_HOME}/features/pedigree

		run_command rm -rf ${PEDIGREE_HOME}/etc/pedigree.xml.temp
	fi
	
	#$ECHO "Hints updated"
				
	##### End of Updating the pedigreee.xml ################
}

backupInstallation(){
	ver=$1

	getMessage TSIN01173I
	echo_msg "\n\n$msg"
	#echo_msg "\n\n-----  Backing up the old product binaries --------"

	run_command cd $PEDIGREE_HOME
	run_command tar -cvf ePedigreeV${ver}_backup.tar * >> $LOG
	run_command cd $TS_HOME/features
	run_command tar -cvf pedigreeV${ver}_backup.tar pedigree >> $LOG
}

backupFiles(){
upgradeFromVer=$1
getMessage TSIN01175I
echo_msg "\n\n$msg"
#echo_msg "\n\n---------  Backing up the current configuration files ------"

if [ ! -f "${TS_HOME}/features/pedigree/pedigree.xml.$upgradeFromVer" ];then
    run_command cp $TS_HOME/features/pedigree/pedigree.xml $TS_HOME/features/pedigree/pedigree.xml.$upgradeFromVer
fi

if [ ! -f "${PEDIGREE_HOME}/bin/pedigree-env.sh.$upgradeFromVer" ];then
    run_command cp $PEDIGREE_HOME/bin/pedigree-env.sh $PEDIGREE_HOME/bin/pedigree-env.sh.$upgradeFromVer
fi

if [ ! -f "{PEDIGREE_HOME}/lib/com.ibm.epcis.pharma.pedigree.ear.$upgradeFromVer" ];then
    run_command cp $PEDIGREE_HOME/lib/com.ibm.epcis.pharma.pedigree.ear $PEDIGREE_HOME/lib/com.ibm.epcis.pharma.pedigree.ear.$upgradeFromVer
fi

if [ ! -f "{$PEDIGREE_HOME}/lib/com.ibm.rfidic.pharma.epedigree.ui.ear.$upgradeFromVer" ];then
    run_command cp $PEDIGREE_HOME/lib/com.ibm.rfidic.pharma.epedigree.ui.ear $PEDIGREE_HOME/lib/com.ibm.rfidic.pharma.epedigree.ui.ear.$upgradeFromVer
fi

if [ ! -f "{$PEDIGREE_HOME}/lib/DocumentPedigree.ear.$upgradeFromVer" ];then
    run_command cp $PEDIGREE_HOME/lib/DocumentPedigree.ear $PEDIGREE_HOME/lib/DocumentPedigree.ear.$upgradeFromVer
fi

}

setVars2(){
	# CONFIG_OPTION = configure | unconfigure
	CONFIG_OPTION=configure
	if [ -z "$was_runas_user" ];then
       	$TS_HOME/bin/startRFIDIC.sh -components=was $credentials >> $LOG
	else
		$TS_HOME/bin/startRFIDIC.sh -components=was $credentials $was_runas >> $LOG
	fi

	if [ -n "$was_admin_user" ]; then
		WSADMIN="wsadmin.sh -profileName $PROFILENAME -conntype SOAP -user ${was_admin_user} -password ${was_admin_password} -wsadmin_classpath $CLASSPATH "
	else
		WSADMIN="wsadmin.sh -profileName $PROFILENAME -wsadmin_classpath $CLASSPATH "
	fi
	
	if [ -n "$NORFIDIC" ]; then
		if [ -n "$was_admin_user" ]; then
			WSADMIN="${WAS_HOME}/bin/wsadmin.sh -profileName $PROFILENAME -conntype SOAP -user ${was_admin_user} -password ${was_admin_password} -wsadmin_classpath $CLASSPATH "
		else
			WSADMIN="${WAS_HOME}/bin/wsadmin.sh -profileName $PROFILENAME -wsadmin_classpath $CLASSPATH "
		fi
	fi
	if [ -z "$was_runas_user" ];then
		was_runas_user="${TS_ADMIN_USER}"
	fi
	
}

updateWASTransactionService(){
    run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/updateTransactionSvcConf.jacl $SERVERNAME $NODENAME $CELLNAME >> $LOG
    echo_msg "\n\n----------  Transaction Service Update Successful -------------"
}

##-------------------------------
## For iFix3 the Epedigree XA data source needs to be recreated with max connections set to 40
##-------------------------------
recreateDataSource(){

	# Using dsOnly option, so not passing in serverName, user, password or jdDesc
	if [ "$DB_TYPE" = "ORACLE" ]; then
		# Determine the Oracle Version
		pedDBVersion
		if [ `echo $DBversion | ${AWK} '{print($1)}'` = "11" ];then
			oraVersion="11g"
		else
			oraVersion="10g"
		fi

    	run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateDatasource.jacl "configure" \
	        $DBMS_ALIAS "RFIDIC Oracle JDBC XA Provider" \
        	"Epedigree XA Data Source" "Oracle Database Settings" \
        	$DBMS_DB_NAME " " $DBMS_PORT $PEDIGREE_DB_HOST jdbc/ibm/epcis/pedigree/dbXA \
        	" " " " "true" $DB_TYPE 40 $ORACLE_JDBC_URL $oraVersion $NORFIDIC >> $LOG
	elif [ "$DB_TYPE" = "DB2" ]; then
        run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateDatasource.jacl "configure" \
    	    $DBMS_ALIAS "RFIDIC DB2 JDBC XA Provider" \
	        "Epedigree XA Data Source" "DB2 Database Settings" \
        	$DBMS_DB_NAME $DB2_SERVER $DBMS_PORT $PEDIGREE_DB_HOST jdbc/ibm/epcis/pedigree/dbXA \
        	" " " " "true" $DB_TYPE 40 " " " " $NORFIDIC >> $LOG
	fi
	echo_msg "\n\n----------  Data Source Update Successful -------------"
}

reinstallEARs(){
	setVars2
	temp1=$WAS_HOME/profiles/$PROFILENAME/config/cells/$CELLNAME/applications/com.ibm.epcis.pharma.pedigreeEAR.ear/deployments/com.ibm.epcis.pharma.pedigreeEAR/com.ibm.epcis.pharma.pedigree.ws.war/WEB-INF/
	temp2=$WAS_HOME/profiles/$PROFILENAME/config/cells/$CELLNAME/applications/com.ibm.epcis.pharma.pedigreeEAR.ear/deployments/com.ibm.epcis.pharma.pedigreeEAR/com.ibm.rfidic.pedigree.mdb.jar/META-INF/
	cp $temp1/ibm-webservicesclient-bnd.xmi /tmp/ibm-webservicesclient-bnd.xmi1
	cp $temp2/ibm-webservicesclient-bnd.xmi /tmp/ibm-webservicesclient-bnd.xmi2
		
	run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/reinstallApplication.jacl "update" \
	$SERVERNAME $NODENAME $CELLNAME "$RFIDIC_SOLDIR/lib/com.ibm.epcis.pharma.pedigree.ear" \
	com.ibm.epcis.pharma.pedigreeEAR "start" >> $LOG

	#runUserCommand $was_runas_user cp /tmp/ibm-webservicesclient-bnd.xmi1 $temp1/ibm-webservicesclient-bnd.xmi 
	#runUserCommand $was_runas_user cp /tmp/ibm-webservicesclient-bnd.xmi2 $temp2/ibm-webservicesclient-bnd.xmi
	rm -rf /tmp/ibm-webservicesclient-bnd.xmi1  
	rm -rf /tmp/ibm-webservicesclient-bnd.xmi2 

	## Pedigree UI EAR
       	cp $WAS_HOME/profiles/$PROFILENAME/installedApps/$CELLNAME/com.ibm.rfidic.pharma.epedigree.uiEAR.ear/com.ibm.rfidic.pharma.epedigree.ui.common.war/xml/Preferences.xml /tmp/PrevUIPreferences.xml
	temp1=$WAS_HOME/profiles/$PROFILENAME/config/cells/$CELLNAME/applications/com.ibm.rfidic.pharma.epedigree.uiEAR.ear/deployments/com.ibm.rfidic.pharma.epedigree.uiEAR/com.ibm.rfidic.pharma.epedigree.ui.war/WEB-INF/
	temp2=$WAS_HOME/profiles/$PROFILENAME/config/cells/$CELLNAME/applications/com.ibm.rfidic.pharma.epedigree.uiEAR.ear/deployments/com.ibm.rfidic.pharma.epedigree.uiEAR/com.ibm.rfidic.pharma.epedigree.ui.partners.war/WEB-INF/
	cp $temp1/ibm-webservicesclient-bnd.xmi /tmp/ibm-webservicesclient-bnd.xmi1
	cp $temp2/ibm-webservicesclient-bnd.xmi /tmp/ibm-webservicesclient-bnd.xmi2
	run_command ${WSADMIN} -f $TS_HOME/bin/jacl/reinstallApplication.jacl "update" \
	    $SERVERNAME $NODENAME $CELLNAME "$RFIDIC_SOLDIR/lib/com.ibm.rfidic.pharma.epedigree.ui.ear" \
	    com.ibm.rfidic.pharma.epedigree.uiEAR "start" >> $LOG
	rm -rf /tmp/PrevUIPreferences.xml  
	#runUserCommand $was_runas_user cp /tmp/ibm-webservicesclient-bnd.xmi1 $temp1/ibm-webservicesclient-bnd.xmi 
	#runUserCommand $was_runas_user cp /tmp/ibm-webservicesclient-bnd.xmi2 $temp2/ibm-webservicesclient-bnd.xmi
	rm -rf /tmp/ibm-webservicesclient-bnd.xmi1  
	rm -rf /tmp/ibm-webservicesclient-bnd.xmi2 

	START_OPTION=no_start
	run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/reinstallApplication.jacl "update" $SERVERNAME $NODENAME $CELLNAME $DOC_PEDIGREE_CAPTURE_APP_LOCATION $DOC_PEDIGREE_CAPTURE_APP_NAME $START_OPTION $CAPTURE_TYPE >> $LOG
	######### End of Settting the client side WS Binding Info ####################

	$TS_HOME/bin/stopRFIDIC.sh -components=was,mq,capture $credentials
	retCode=$?
	if [ "$retCode" != 0 -a "$retCode" != 246 ];then
		getMessage TSIN01179E $retCode
		echo_msg "\n$msg"
		#echo_msg "\nThe stopRFIDIC.sh command returned a non-zero code $retCode. You may need to restart WAS manually"
	fi
	if [ -z "$was_runas_user" ];then
		$TS_HOME/bin/startRFIDIC.sh -components=was,mq,capture $credentials
	else
		$TS_HOME/bin/startRFIDIC.sh -components=was,mq,capture $credentials $was_runas
	fi
	retCode=$?
	if [ "$retCode" != 0 -a "$retCode" != 127 ];then
		getMessage TSIN01180E $retCode
		echo_msg "\n$msg"
		#echo_msg "\nThe startRFIDIC.sh command returned a non-zero code $retCode. You may need to restart WAS manually"
	fi
	echo_msg "\n\n----------  WAS Migration Successful -------------"
	return 0
}


correctDBARights(){
	getMessage TSIN01215I
   	echo_msg "\n$msg"
	#echo_msg "Correcting old DBA rights..."
    searchStr[0]='${old_dba_user}'
	replaceStr[0]="$DBMS_ADMIN_USER"
	asciiUpdate "$revoke_priv_file" $searchStr $replaceStr
	${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${revoke_priv_file}>> $LOG 2>>$LOG
	ret=$?
	if [ $ret -ne 0 ];then
	  getMessage TSIN02101E
   	  echo_msg "\n$msg"
	  #echo_msg "Revoke DBA Privileges failed. This is OK if Pedigree and TS share the same database"
    else
	  getMessage TSIN01217I
   	  echo_msg "\n$msg"
         #echo_msg "Revoke DBA Privileges Succeeded"
    fi
	grantPrivileges	
	if [ -z "$was_runas_user" ];then
        $TS_HOME/bin/startRFIDIC.sh -components=was,mq $credentials
	else
		$TS_HOME/bin/startRFIDIC.sh -components=was,mq $credentials $was_runas
	fi
	return 0
}

grantPrivileges(){
	searchStr[0]='${non_dba_user}'
	replaceStr[0]="$DBMS_ADMIN_USER"
	
	asciiUpdate "$grant_trace_priv_file" $searchStr $replaceStr
	${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${grant_trace_priv_file}>> $LOG 2>>$LOG
	ret=$?
	if [ $ret -ne 0 ];then
		getMessage TSIN02055E 
		echo_msg "\n$msg"
		echo_msg "Granting of privileges on pedigree database for non-DBA - event Ped-rights not successful."
        return $ret
	fi
	searchStr[0]='${non_dba_user}'
	replaceStr[0]="$DBMS_ADMIN_USER"
	asciiUpdate "$grant_docPed_priv_file" $searchStr $replaceStr
	${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${grant_docPed_priv_file}>> $LOG 2>>$LOG
	ret=$?
	if [ $ret -ne 0 ];then
		getMessage TSIN02044E
   	   	echo_msg "\n$msg"
		#echo_msg "Granting of privileges on pedigree database for non-DBA - docPed-rights not successful. This could be because DocPedigree is not installed on the system"
 	fi
}


assignLogFile(){
	logName=$1
	if [ -z "$LOG" ];then
		LOG=${scriptDir}/$logName.log
	fi
	
	if [ -f "$LOG" ];then
		index=0
		while [ "$index" -lt "10" ]
	        do
	            index=`expr $index + 1`
	       	    LOG=${scriptDir}/$logName-$index.log
	            if [ ! -f "$LOG" ];then
			break
		    fi
	        done

		if [ -f "$LOG" ];then
			#getMessage TSIN01314W
			#echo_msg "$msg"
			echo "Please delete or archive all old log files and then continue"
			exit
		fi
	fi
}

checkPedHome() {
	# Check if the PEDIGREE_HOME is correct
	if [ -z "$PEDIGREE_HOME" ]; then
	        	PEDIGREE_HOME=/opt/ibm/InfoSphere/pedigree
			echo_msg "------------------------------------------------------"
			getMessage TSIN02086I $PEDIGREE_HOME
			echo_msg "$msg"
	        	#echo_msg "PEDIGREE_HOME was not set in the environment. Setting it to $PEDIGREE_HOME."
			echo_msg "------------------------------------------------------"
	fi
	if  [ ! -d $PEDIGREE_HOME"/etc" ]
	then
		echo_msg "------------------------------------------------------"
	    getMessage TSIN02087E 
	    echo_msg "$msg"
	    #echo_msg "$PEDIGREE_HOME is not a valid Pedigree installation directory. Exiting upgradation process."
		echo_msg "------------------------------------------------------"
	    usage
	fi
}

checkDiskSpace() {
		
		#### Check for available disk space ################
		getMessage TSIN01032I
		echo_msg "\n$msg"

		if [ "$OS" = "SunOS" ];then
			 DF_OPTIONS="-k"
		else
			 DF_OPTIONS="-Pk"
		fi
		
		SPACE=`df $DF_OPTIONS "$PEDIGREE_HOME" | tail -1 | awk '{ print $4 }'`
		TMP_SPACE=`df $DF_OPTIONS /tmp | tail -1 | awk '{ print $4 }'`
		
		#Check to ensure 1 GB free space is available for migration 
		if [ "$SPACE" -lt 1048576 ]
		then
				clear
				getMessage TSIN01033E
				echo_msg "$msg"
				#echo_msg "Install >> Platform Verification >> Error"
				echo_msg "--------------------------------------------------"
				getMessage TSIN02088E
	    			echo_msg "\n $msg"
				#echo_msg "\n ePedigree requires 1 GB for migration"
				exit 1
		fi
		#Check to ensure 500 MB free space is available in /tmp for migration 
		if [ "$TMP_SPACE" -lt 512000 ]
		then
				clear
				getMessage TSIN01033E
				echo_msg "$msg"
				#echo_msg "Install >> Platform Verification >> Error"
				echo_msg "--------------------------------------------------"
				getMessage TSIN02089E
	    			echo_msg "\n$msg"
				#echo_msg "\nIBM ePedigree requires 500 MB in /tmp for migration"
				exit_install
		fi
		getMessage TSIN01036I
		echo_msg "$msg"
		#echo_msg "diskspace verified."
		sleep 2
}

verifyUser(){
	getMessage TSIN01037I
	echo_msg "\n$msg"
	#echo_msg "\nVerifying the privileges of current user..."
	user_id=`${USERID}`
	if [ "$no_rfidic" = "false" ];then
		if [ ! "$CURRENT_USER" = "$TS_ADMIN_USER" ];then
			#echo_msg "Privileges of current user verified."
		#else
			clear
			getMessage TSIN01033E
			echo_msg "$msg"
			#echo_msg "Install >> Platform Verification >> Error"
			echo_msg "--------------------------------------------------"
			getMessage TSIN02163E $TS_ADMIN_USER
			echo_msg "$msg"
			#echo_msg "The ePedigree migration should be run as the rfidic user $TS_ADMIN_USER. Retry install as the user $TS_ADMIN_USER."
			exit 1
		fi
	fi
	if [ "$install" = "true" ];then
		if [ ! "$was_user" = "$TS_ADMIN_USER" ];then
			echo "test" | sudo -S -p " " -l > /tmp/sudoCheck.txt 2>&1
			retcode=$?
			#echo "ReturnCode $retcode"
			if [ $retcode -ne 0 ];then
			    getMessage TSIN02170E $TS_ADMIN_USER
			    echo_msg "$msg"
				#echo_msg "ePedigree installation on WebSphere Application Server with security ON requires '$TS_ADMIN_USER' in the sudoers list"
				getMessage TSIN02171E $TS_ADMIN_USER
				echo_msg "$msg"
				#echo_msg "Add the entry - ('$TS_ADMIN_USER'  ALL=(ALL)  NOPASSWD: ALL) to the sudoers file"
				getMessage TSIN02172E $TS_ADMIN_USER
				echo_msg "$msg"
				#echo_msg "Provide sudo access to the $TS_ADMIN_USER and then continue with the installation "
				exit 1
			fi
			rm -rf /tmp/sudoCheck.txt
		fi
	fi

}

setVars(){
	if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
		 getMessage TSIN01153I $was_admin_user
		 echo_msg "$msg"
	     	 #echo_msg "Enter the password for the $was_admin_user WebSphere Application Server (WAS) user:"
	       stty -echo
		 read was_admin_password
		 stty echo
	fi
	
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
	    credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
	    wsadmin_credentials="-conntype SOAP -user $was_admin_user -password $was_admin_password"
		WSADMIN="wsadmin.sh -conntype SOAP -user ${was_admin_user} -password ${was_admin_password} -wsadmin_classpath $CLASSPATH"
		ENDPOINT_URL_PREFIX="https://${TS_HOST}:${RFIDIC_PORT}"
	else
		WSADMIN="wsadmin.sh -wsadmin_classpath $CLASSPATH"
		ENDPOINT_URL_PREFIX="http://${TS_HOST}:${RFIDIC_PORT}"
	fi
	if [ -n "$was_runas_user" ];then
		  was_runas="-was_runas_user=$was_runas_user"
	fi
}

upgrade(){
	upgradeFromVer=$1
	upgradeToVer=$2
	checkPedHome
	checkDiskSpace
	verifyUser
	setVars

	if  [ -z "$PEDIGREE_BUILD_PATH" ]
	then
		echo_msg "------------------------------------------------------"
	    getMessage TSIN02068E $PEDIGREE_BUILD_PATH
	    echo_msg "$msg"
	    #echo_msg "PEDIGREE_BUILD_PATH was not set in the environment. Pedigree v$upgradeToVer installables not found."
	    getMessage TSIN01195E
	    echo_msg "$msg"
		#echo_msg "Exiting upgradation process."
		echo_msg "------------------------------------------------------"
	    usage
	fi
	#displayLA ${PEDIGREE_BUILD_PATH}   Do not need to show License for IFIX
	
	# In case of remote db, the data backup operation will fail.
	# Set backup_data to false if db is remote.
	
	if [ ! "$ped_db_dist" = "0" ];then
		backup_data="false"
	fi
	
	if [ "$migrate_only" = "true" ];then
		echo_msg "migrate_only is true"
		# include the RFIDIC environment settings
		. $PEDIGREE_HOME/bin/pedigree-env.sh
		getDBConfig
		migrate
		printStatus
	fi
	if [ -z "$BACKUP_OLD_INSTALLATION" ];then
		getMessage TSIN02092I
	   	echo_msg "$msg"
		#echo_msg "Do you want to backup the existing Pedigree binaries? (y/n)"
		read ans
		if [ "$ans" = "y" -o "$ans" = "Y" ];then
			backupInstallation $upgradeFromVer
		fi
	elif [ "$BACKUP_OLD_INSTALLATION" = "Y" ] || [ "$BACKUP_OLD_INSTALLATION" = "y" ]
	then
		backupInstallation $upgradeFromVer
	fi
	
	backupFiles $upgradeFromVer
}	

correctDBSettings()
{
		# The jdbc jars will need to be picked from the DBMS_HOME dir for a local DB
		# And the path needs to be specified by user if it is remote DB
		# If the upgrade path is from AMP-MOD1-MOD2 -then the DBMS_JDBC_LIB path
		# may be pointing to $TS_HOME. Therefore we need to ensure that is not the case.
		
		if [ -z "$PED_DBMS_LIB_HOME" ];then
			PED_DBMS_LIB_HOME=$DBMS_HOME_LIB
		fi
		
		if [ -z "$PEDIGREE_MQ_HOST" ];then
			PEDIGREE_MQ_HOST=`cat $TS_HOME/features/pedigree/pedigree.xml | grep "HOST_NAME" | awk -F '="' '{print($3)}' | awk -F '"/' '{print($1)}'`
		fi
		
		${ECHO} $PED_DBMS_LIB_HOME | grep "$TS_HOME/bin/"
		if [ $? != 0 ];then
			getMessage TSIN01234W
	   		echo_msg "$msg"
			#echo_msg "JDBC Lib path is not pointing to RFIDIC HOME. So proceeding with upgrade... "
			DBMS_JDBC_LIB_PATH=$PED_DBMS_LIB_HOME
		else
			getMessage TSIN01235I
			echo_msg "$msg"
			#echo_msg "JDBC Lib path is pointing to RFIDIC jars...Hence resetting."
			if [ -z "$DBMS_JDBC_LIB_PATH_NEW" ];then
				distributed $PEDIGREE_DB_HOST
				db_dist=$?
				if [ "$db_dist" = "0" ];then
					getMessage TSIN01236I
					echo_msg "$msg"
					#echo_msg "Local DB. Hence Pointing it to local DBMS_HOME JDBC Path"
					if [ "$DB_TYPE" = "INFORMIX" ];then
						DBMS_JDBC_LIB_PATH=$DBMS_HOME/jdbc/lib
					elif [ "$DB_TYPE" = "ORACLE" ];then
						DBMS_JDBC_LIB_PATH=$DBMS_HOME/jdbc/lib
					elif [ "$DB_TYPE" = "DB2" ];then
						DBMS_JDBC_LIB_PATH=$DBMS_HOME/java
					fi
				else
					getMessage TSIN01237I
					echo_msg "\n$msg"
					#echo_msg "\nEnter the path to the JDBC drivers jars on the local machine: "
					read DBMS_JDBC_LIB_PATH
					if [ -z "$DBMS_JDBC_LIB_PATH" ];then
						getMessage TSIN01238E
						echo_msg "$msg"
						#echo_msg "JDBC drivers path not set. Re-run the upgrade script passing DBMS_JDBC_LIB_PATH_NEW as a parameter."
						usage
						exit
					fi
				fi
			else
				getMessage TSIN01239I $DBMS_JDBC_LIB_PATH_NEW
				echo_msg "$msg"
				#echo_msg "Resetting the JDBC Lib path to the one given by user $DBMS_JDBC_LIB_PATH_NEW"
				DBMS_JDBC_LIB_PATH=$DBMS_JDBC_LIB_PATH_NEW
			fi
		fi	
		PED_DBMS_LIB_HOME=$DBMS_JDBC_LIB_PATH
}

superMigrate(){
	# Migrate WAS
	getMessage TSIN02093I
	echo_msg "$msg"
	#echo_msg "Updating WAS configuration..."
	. $PEDIGREE_HOME/bin/pedigree-env.sh
	getDBConfig
	migrate
	printStatus
	
}

printStatus(){
	if [ ! "$wascode" = "0" ];then
		echo_msg "---------------------------------------------------"
		getMessage TSIN02186E "v2.5.0.0 JP IFIX-003"
		echo_msg "$msg"
	      #echo_msg "Upgradation to Pedigree v$upgradeToVer was successful but WAS migration failed. WAS reconfiguration can be done later manually."
		echo_msg "---------------------------------------------------"
	fi
	if [ ! "$dbcode" = "0" ];then
		echo_msg "---------------------------------------------------"
		getMessage TSIN02187E "v2.5.0.0 JP IFIX-003"
		echo_msg "$msg"
	      #echo_msg "Upgradation to Pedigree v$upgradeToVer was successful but DB migration failed. DB reconfiguration can be done later manually."
		echo_msg "---------------------------------------------------"
	fi
	if [ "$wascode" = "0" -a "$dbcode" = "0" ];then
		echo_msg "---------------------------------------------------"
		getMessage TSIN02188I "v2.5.0.0 JP IFIX-003"
		echo_msg "$msg"
		#echo_msg "ePedigree {0} was installed successfully.."
		echo_msg "---------------------------------------------------"	
	fi
	exit 0

}
replaceStorageOptions()
{
	#Replace the TableSpace value in the SQL scripts if specified else replace the TABLESPACE clause itself
	searchStr[0]='${storage_opts}'
	if [ -z "$DB_TABLE_SPACE" ];then
		replaceStr[0]=""
	else
		if [ "$DB_TYPE" = "ORACLE" ];then
			replaceStr[0]=" TABLESPACE $DB_TABLE_SPACE "
		else
			replaceStr[0]=" in $DB_TABLE_SPACE "
		fi
	fi
	asciiUpdate "$1" "$searchStr" "$replaceStr"
}

pause()
{
	if [ "$SILENT" = "Y" ];then
		return
	fi
	getMessage TSIN01002I
	echo_msg "\n\n\n$msg"
	#echo_msg "\n\n\nPress <<ENTER>> to continue."
	read dummy
	return
}

# Copies message jars to temp folder
copyMsgFiles(){
	#### Extract the messages tar to tmp folder ########
	unset msg_cp
	run_command mkdir -p /tmp/pedExtract
	chmod 777 /tmp/pedExtract
	PEDIGREE_BUILD_PATH=$1
	if [ -n "$TS_HOME" ];then
		if [ ! -f "$TS_HOME/bin/tsEnv.sh" ]; then
			echo_msg "Ensure that the IBM InfoSphere Traceability Server installation directory is correct and retry install."
			exit 1
		fi
	else
		echo_msg "Ensure that the IBM InfoSphere Traceability Server installation directory is correct and retry install."
		exit 1

	fi
		
	run_command cp ${PEDIGREE_BUILD_PATH} /tmp/pedExtract/epedigree.zip
	run_command cd /tmp/pedExtract
	
	run_command unzip /tmp/pedExtract/epedigree.zip >>/dev/null
	
	## Missing client_com.ibm.rfidic.utils.jar
	run_command cd ${scriptDir}
	msg_cp=${TS_HOME}/lib/com.ibm.rfidic.messages.jar:${TS_HOME}/lib/com.ibm.rfidic.utils.messages.jar:/tmp/pedExtract/ts/lib/com.ibm.rfidic.pharma.epedigree.messages.jar:${TS_HOME}/lib/com.ibm.imc.algorithms.jar:${TS_HOME}/lib/icu4j-4_4_1.jar:${TS_HOME}/lib/commons-lang-2.4.jar

	rm -rf /tmp/pedExtract/epedigree.zip
	export msg_cp

	TS_WAS_HOME=`grep "WAS_HOME=" ${TS_HOME}/bin/tsEnv.sh | head -1 | ${AWK_EQUAL} '{print($2)}'`
}

getMessage(){
	unset msg
	#echo "${WAS_HOME}/java/bin/java -classpath $msg_cp com.ibm.rfidic.messages.tools.RFIDICGetMessage -noid "$@" "	
	msg=`${TS_WAS_HOME}/java/bin/java -classpath $msg_cp com.ibm.rfidic.messages.tools.RFIDICGetMessage -noid "$@"`
	#echo "The message is $msg"
}

clearMsgFiles(){
	rm -rf /tmp/pedExtract
}

