#!/bin/ksh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# (C) COPYRIGHT International Business Machines Corp. 2008, 2012
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# 
# installPedigree.sh - install and configure the pedigree modules
###############################################################################################################

sDir=`dirname ${0}`
scriptDir=`cd $sDir && pwd`
. ${scriptDir}/inst-upgr-ped-env.sh


usage(){
	#getMessage TSIN02001I
	#echo_msg "$msg"
	echo_msg "USAGE: ./installPedigree.sh -configure_only -log=<log-file path> [-dba_user=<value>] [-dba_password=<value>]"
	exit 1
}

refresh(){
	getMessage TSIN01003I
	echo_msg "$msg"
	#echo_msg "Press 1 to go to the next screen"
	getMessage TSIN01004I
	echo_msg "$msg"
	#echo_msg "Press 2 to refresh"
	getMessage TSIN01005I
	echo_msg "$msg"
	#echo_msg "Press 3 to exit the installation"
	read ans
	if [ "$ans" = "1" ];then
		return 0
	elif [ "$ans" = "2" ];then
		main
	elif [ "$ans" = "3" ];then
		exit_confirm
		ex_ret=$?
		if [ $ex_ret -eq 1 ];then
			refresh
		fi
	else
		getMessage TSIN01011E
		echo_msg "$msg"
		#echo_msg "Invalid input. Try again."
		refresh
       fi	
}

refresh_HealthCheck(){
	getMessage TSIN01012E
	echo_msg "\n$msg"
	#echo_msg "\nOne or more pre-requisite software services might not be started. Start the service(s) and \n"
	getMessage TSIN01006I
	echo_msg "$msg"
	#echo_msg "Press 1 to refresh"
	getMessage TSIN01007I
	echo_msg "$msg"
	#echo_msg "Press 2 to exit the installation"
	read ans
	if [ "$ans" = "1" ];then
		HealthCheck
	elif [ "$ans" = "2" ];then
		exit_confirm
			ex_ret=$?
		if [ $ex_ret -eq 1 ];then
			refresh_HealthCheck
		fi		
	else
		getMessage TSIN01011E
		echo_msg "$msg"
		#echo_msg "Invalid input. Try again."
		refresh_HealthCheck
       fi
}


continueOrExit(){
	if [ "$SILENT" = "Y" ];then
		return
	fi
	getMessage TSIN01015I
	echo_msg "\n\n\n$msg"
	#echo_msg "\n\n\nDo you want to continue?"
	getMessage TSIN01008I
	echo_msg "$msg"
	#echo_msg "Enter 1 to Continue or 2 to Exit"
	read ans
	if [ "$ans" = "1" ];then
		return
	elif [ "$ans" = "2" ];then
		exit_confirm
		ex_ret=$?
		if [ $ex_ret -eq 1 ];then
			continueOrExit
		fi		
	else
		getMessage TSIN01011E
		echo_msg "$msg"
		#echo_msg "Invalid input. Try again."
		continueOrExit
       fi
}


exit_checkRFIDIC(){
	echo_msg "\n\nPress 1 to overwrite the existing version of IBM InfoSphere Traceability Server and go to the next screen"
	echo_msg "Press 2 to exit the installation"
	read ans
	if [ "$ans" = "1" ];then
		return
	elif [ "$ans" = "2" ];then
		exit_confirm
		ex_ret=$?
		if [ $ex_ret -eq 1 ];then
			exit_checkRFIDIC
		fi		
	else
		echo_msg "Invalid input. Try again."
		exit_checkRFIDIC
       fi
}

exit_confirm(){
	getMessage TSIN01016I
	echo_msg "\n$msg"
	#echo_msg "\nAre you sure you want to exit?"
	getMessage TSIN01010I
	echo_msg "$msg"
	#echo_msg "Press 1 to cancel"
	getMessage TSIN01007I
	echo_msg "$msg"
	#echo_msg "Press 2 to exit the installation"
	read ans
	if [ "$ans" = "1" ];then
		return 1
	elif [ "$ans" = "2" ];then
		clearMsgFiles
		exit 1		
	else
		getMessage TSIN01011E
		echo_msg "$msg"
		#echo_msg "Invalid input. Try again"
		exit_confirm
	fi
}

exit_install(){
if [ "$SILENT" = "Y" ];then
	clearMsgFiles
	exit 1
fi

getMessage TSIN01007I
echo_msg "\n$msg"
#echo_msg "\nPress 2 to exit the installation"
read ans
if [ "$ans" = "2" ];then
	clearMsgFiles
	exit 1		
else
	getMessage TSIN01011E
	echo_msg "$msg"
	#echo_msg "Invalid input. Try again"
	exit_install
fi
}

pedDBVersion(){
if  [ -z "$DBversion" ];then
	unset cp
	unset dbstatus

	run_command cd ${scriptDir}
	cp=/tmp/pedExtract/ts/lib/com.ibm.rfidic.pedigree.install.syscheck.jar:$TS_HOME/lib/commons-dbutils-1.1.jar:$WAS_HOME/lib/j2ee.jar:${TS_HOME}/lib/commons-logging.1.1.1.jar:$TS_HOME/lib/commons-codec-1.3.jar:$TS_HOME/lib/commons-httpclient-3.1.jar

	if [ "$DB_TYPE" = "ORACLE" ];then
		cp=$cp:$DBMS_JDBC_LIB_PATH/ojdbc6.jar
		JDBC="jdbc:oracle:thin:@${PEDIGREE_DB_HOST}:${ORACLE_PORT_NUMBER}:${DB_NAME}"
		OracleDriver=oracle.jdbc.OracleDriver
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${OracleDriver} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PWD} ${TS_HOME}/bin/Oracle/VersionCheck.sql  1>&2 > /tmp/VersionOutput.txt
		dbstatus=`echo $?`
		if [ "$dbstatus" = "1" ];then
			echo_msg "\n Database version cannnot be retrieved on host - ${PEDIGREE_DB_HOST} , Check if the DB is running and try again ."
			exit_install
		fi
		DBversion=`cat /tmp/VersionOutput.txt | grep "Release" | awk '{print($7)}'`

	elif [ "$DB_TYPE" = "DB2" ];then
		cp=$cp:$DBMS_JDBC_LIB_PATH/db2jcc.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cu.jar
		JDBC="jdbc:db2://${PEDIGREE_DB_HOST}:${DB2_PORT_NUMBER}/${DB_NAME}"
		DB2Driver=com.ibm.db2.jcc.DB2Driver
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${DB2Driver} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PWD} ${TS_HOME}/bin/DB2/VersionCheck.sql  1>&2 > /tmp/VersionOutput.txt
		dbstatus=`echo $?`
		if [ "$dbstatus" = "1" ];then
			echo_msg "\n Database version cannnot be retrieved on host - ${PEDIGREE_DB_HOST} , Check if the DB is running and try again ."
			exit_install
		fi
		DBversion=`cat /tmp/VersionOutput.txt | grep "DB2" | ${TAIL}1 | awk '{print($2)}'`
	fi

	rm -f /tmp/VersionOutput.txt
fi

}

#### Check for OS level ######################
prereqCheck(){

getMessage TSIN01020I
echo_msg "\n$msg"
#echo_msg "\nVerifying the operating system level..."

futureRelease=$FALSE
invalidOS=$FALSE
unknownOS=$FALSE

if [ "$OS" = "Linux" ];then
	if [ -f "/etc/redhat-release" ];then
		release=`cat /etc/redhat-release | awk '{print($7)}' | ${AWK} '{print($1)}'`
		
		if [ "$release" -gt 5 ];then
			futureRelease=$TRUE
		fi
		if [ "$release" -lt 5 ];then
			invalidOS=$TRUE
		fi
			
	elif [ -f "/etc/SuSE-release" ];then
			release=`cat /etc/SuSE-release | grep "VERSION" | awk '{print($3)}'`

			if [ "$release" -gt 11 ];then
				futureRelease=$TRUE
				
			elif [ "$release" -lt 10 ];then
				invalidOS=$TRUE
			fi
	else
			unknownOS=$TRUE
	fi
	
elif [ "$OS" = "AIX" ];then
	release=`uname -a | awk '{print($4)}'`
	update=`uname -a | awk '{print($3)}'`
	
	if [  "$release" -lt 6  ];then
		invalidOS=$TRUE
	elif [  "$release" = "6"  ];then
		if [ "$update" -lt 1 ];then
			invalidOS=$TRUE
		elif [ "$update" -gt 1 ];then
			$futureRelease=$TRUE
		fi
	else
		$futureRelease=$TRUE
	fi
	 
elif [ "$PLATFORM" = "SunOS" ];then
    osLevel=`uname -r`
	release=`echo $osLevel | ${AWK_PERIOD} '{print($1)}'`
	version=`echo $osLevel | ${AWK_PERIOD} '{print($2)}'`

	if [ "$release" = 5 ];then
		if [ "$version" -lt 10 ];then
			invalidRelease=$TRUE
		elif [ "$version" -gt 10 ];then
			futureRelease=$TRUE
		fi
	elif [ "$release" -gt "5" ];then
		futureRelease=$TRUE
	fi
	
else
	unknownOS=$TRUE
fi

if [ "$futureRelease" = "$TRUE" ];then
		getMessage TSIN01021W
		echo_msg "$msg"
		#echo_msg "Support for your operating system might have been added after the release of the product."
		getMessage TSIN01022W
		echo_msg "$msg"
		#echo_msg "You can continue with the installation, but the installation might not succeed."
		getMessage TSIN01023E
		echo_msg "$msg"
		#echo_msg "See the web page on the hardware and software prerequisites for more details."
		continueOrExit
fi

if [ "$unknownOS" = "$TRUE" -o "$invalidOS" = "$TRUE" ];then
	clear
	getMessage TSIN01033E
	echo_msg "$msg"
	#echo_msg "Install >> Platform Verification >> Error"
	echo_msg "--------------------------------------------------"
	getMessage TSIN02003E
	echo_msg "\n$msg"
	#echo_msg "\nePedigree is not supported for this operating system.."
	getMessage TSIN01025E
	echo_msg "$msg"
	#echo_msg "Install a supported operating system and then try installing."
	getMessage TSIN01023E
	echo_msg "$msg"
	#echo_msg "See the web page on the hardware and software prerequisites for more details."
	exit_install
fi 

getMessage TSIN01027I
echo_msg "$msg"
#echo_msg "Operating system level verified."
sleep 2

#### Check for hostname ####################

getMessage TSIN01028I
echo_msg "\n$msg"
#echo_msg "\nVerifying the hostname..."

if [ "$HOSTNAME" = "localhost" -o "$HOSTNAME" = "localhost.localdomain" ];then
	clear
	getMessage TSIN01033E
	echo_msg "$msg"
	#echo_msg "Install >> Platform Verification >> Error"
	echo_msg "--------------------------------------------------"
	getMessage TSIN01029E $HOSTNAME 
	echo_msg "\n$msg"
	#echo_msg "\n$HOSTNAME is not a valid hostname."
	getMessage TSIN01030E
	echo_msg "$msg"
	#echo_msg "Reset the hostname and then try installing."
	exit_install
fi

getMessage TSIN01031I
echo_msg "$msg"
#echo_msg "Hostname verified."
sleep 2

if [ ! -d ${PEDIGREE_HOME} ];then
	run_command mkdir -p ${PEDIGREE_HOME}
fi

checkDiskSpace
verifyUser
MQ_GROUP="mqm"
mq_grep=`echo $user_id | grep $MQ_GROUP`
if [ -z "$mq_grep" ];then
	clear
	getMessage TSIN01033E
	echo_msg "$msg"
	#echo_msg "Install >> Platform Verification >> Error"
	echo_msg "--------------------------------------------------"
	getMessage TSIN02007E $CURRENT_USER $MQ_GROUP
	echo_msg "$msg"
	#echo_msg "Ensure that the user $CURRENT_USER is part of the group $MQ_GROUP and then try install again."
	exit_install
fi

getMessage TSIN01039I
echo_msg "$msg"
#echo_msg "Privileges of current user verified."
}


displaySummary(){
clear
getMessage TSIN01045I
echo_msg "$msg"
#echo_msg "Install >> Information Verfication >> Summary >> WAS Properties"
echo_msg "----------------------------------------------------------------"
echo_msg "\nWAS_HOME='$WAS_HOME'\n"
echo_msg "WAS_RUNAS_USER='$was_user'\n"
echo_msg "NODENAME='$NODENAME'\n"
echo_msg "CELLNAME='$CELLNAME'\n"
echo_msg "SERVERNAME='$SERVERNAME'\n"
getMessage TSIN02008W
echo_msg "\n\n$msg\n"
#echo_msg "\n\nUpdate incorrect values, if any, in setPedigreeEnv.sh, and refresh the installation.\n"
refresh

### Displaying MQ Information  ###########################
clear
getMessage TSIN01047I
echo_msg "\n$msg"
#echo_msg "\nInstall >> Information Verification >> Summary >> MQ Properties"
echo_msg "----------------------------------------------------------------"
echo_msg "\nMQ_HOME='$MQ_HOME'\n"
echo_msg "MQ_LSR_PORT='$MQ_LSR_PORT'\n"
echo_msg "MQ_QUEUE_MANAGER='$MQ_QUEUE_MANAGER'\n"
echo_msg "MQ_USER='$MQ_USER'\n"
echo_msg "MQ_USER_PASSWORD='$MQ_USER_PASSWORD'\n"
echo_msg "MQ_SERVER_HOST='$PEDIGREE_MQ_HOST'\n"
echo_msg "DOCPEDIGREE_QUEUE='$DOCPEDIGREE_QUEUE'\n"
echo_msg "QNAME_PEDIGREE_EVENT='$QNAME_PEDIGREE_EVENT'\n"
echo_msg "MDM_CHANGE_NOTIF_QUEUE_NAME='$MDM_CHANGE_NOTIF_QUEUE_NAME'\n"
getMessage TSIN02008W
echo_msg "\n\n$msg\n"
#echo_msg "\n\nUpdate incorrect values, if any, in setPedigreeEnv.sh, and refresh the installation.\n"
refresh


### Displaying Database Information  ###########################
clear
getMessage TSIN01048I
echo_msg "\n$msg"
#echo_msg "\nInstall >> Information Verification >> Summary >> Database Properties"
echo_msg "----------------------------------------------------------------"
echo_msg "\nDB_TYPE='$DB_TYPE'\n"
echo_msg "DBMS_HOME='$DBMS_HOME'\n"
echo_msg "DBMS_SERVER_HOST='$PEDIGREE_DB_HOST'\n"
echo_msg "DBMS_JDBC_LIB_PATH='$DBMS_JDBC_LIB_PATH'\n"
echo_msg "DBMS_ADMIN_USER='$DBMS_ADMIN_USER'\n"
echo_msg "DBMS_ADMIN_PWD='$DBMS_ADMIN_PWD'\n"
echo_msg "DBMS_DB_NAME='$DB_NAME'\n"

if  [ "$DB_TYPE" = "ORACLE" ];then
	echo_msg "ORACLE_GROUP='$ORACLE_GROUP'\n"
	echo_msg "ORACLE_PORT_NUMBER='$ORACLE_PORT_NUMBER'\n"
fi
if  [ "$DB_TYPE" = "DB2" ];then
	echo_msg "DB2_INSTANCE='$DB2_INSTANCE'\n"
	echo_msg "DB2_PORT_NUMBER='$DB2_PORT_NUMBER'\n"
fi
getMessage TSIN02008W
echo_msg "\n\n$msg\n"
#echo_msg "\n\nUpdate incorrect values, if any, in setPedigreeEnv.sh, and refresh the installation.\n"
refresh

### Displaying Other Information  ###########################
clear
getMessage TSIN01049I
echo_msg "\n$msg"
#echo_msg "\nInstall >> Information Verification >> Summary >> Other Properties"
echo_msg "----------------------------------------------------------------"
echo_msg "\nPEDIGREE_BUILD_PATH='$PEDIGREE_BUILD_PATH'\n"
echo_msg "PEDIGREE_HOME='$PEDIGREE_HOME'\n"
echo_msg "TS_HOME='$TS_HOME'\n"
echo_msg "TS_HOST='$TS_HOST'\n"
echo_msg "TS APPLICATION PORT NUMBER='$TS_APP_PORT'\n"
echo_msg "CAPTURE TYPE='$CAPTURE_TYPE'\n"
echo_msg "DOC PEDIGREE CAPTURE BUS='$Document_capture_bus'\n"
echo_msg "DOC PEDIGREE SERVICE BUS='$Document_service_bus'\n"

getMessage TSIN02008W
echo_msg "\n\n$msg\n"
#echo_msg "\n\nUpdate incorrect values, if any, in setPedigreeEnv.sh, and refresh the installation.\n"
refresh
}

missingInfo(){

distributed $PEDIGREE_DB_HOST
db_dist=$?

distributed $PEDIGREE_MQ_HOST
mq_dist=$?

#### Check for any missing but required info ###############
if  [ -z "$WAS_HOME" ];then
	 getMessage TSIN01050E
	 missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'WAS_HOME' is empty"
elif  [ ! -f "$WAS_HOME/bin/versionInfo.sh" ];then
	 getMessage TSIN02009E $WAS_HOME
	 missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'WAS_HOME' - $WAS_HOME does not seem to be valid"
        unset WAS_HOME
fi
if  [ -z "$DB_TYPE" ];then
	 getMessage TSIN01051E
	 missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'DB_TYPE' is empty"
fi
if  [ -z "$DBMS_HOME" ];then

	if [ "$db_dist" = "0" ];then
		getMessage TSIN01052E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'DBMS_HOME' is empty"
	elif [ "$db_dist" = "1" ];then
		if [ "$DB_TYPE" = "ORACLE" ];then
			DBMS_HOME=$TS_HOME/Oracle
		elif [ "$DB_TYPE" = "DB2" ];then
			DBMS_HOME=$TS_HOME/DB2
		fi
	fi
elif  [ ! -d $DBMS_HOME -a "$db_dist" = "0" ];then
	 getMessage TSIN02010E $DB_HOME
	 missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'DBMS_HOME' - $DBMS_HOME does not seem to be valid"
        unset DBMS_HOME;unset DBMS_JDBC_LIB_PATH;
fi
if  [ -z "$DBMS_ADMIN_USER" ];then
	 getMessage TSIN01053E
	 missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'DBMS_ADMIN_USER' is empty"
fi
if  [ -z "$DBMS_ADMIN_PWD" ];then
	 getMessage TSIN01054E
	 missing_info=$missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'DBMS_ADMIN_PWD' is empty"
fi

if  [ -z "$DBMS_JDBC_LIB_PATH" ];then
     getMessage TSIN01055E
     missing_info=$missing_info"\n$msg"
    #missing_info=$missing_info"\nThe value for 'DBMS_JDBC_LIB_PATH' is empty"
fi

if [ -n "$DBMS_JDBC_LIB_PATH" -a -n "$WAS_HOME" ];then
	# Verify req jars are present under DBMS_JDBC_LIB_PATH
	if  [ "$DB_TYPE" = "ORACLE" ];then
		if [ ! -f "$DBMS_JDBC_LIB_PATH/ojdbc6.jar" ];then
				getMessage TSIN01056E $DBMS_JDBC_LIB_PATH
	 			missing_info=$missing_info"\n$msg"
				#missing_info=$missing_info"\nOne or more required JDBC drivers not present under $DBMS_JDBC_LIB_PATH or not readable by the current user."
				getMessage TSIN01057E
	 			missing_info=$missing_info"\n$msg"
				#missing_info=$missing_info"\nSpecify the correct value for 'DBMS_JDBC_LIB_PATH'"
		fi	
	fi
	if  [ "$DB_TYPE" = "DB2" ];then
		license_file=`ls $DBMS_JDBC_LIB_PATH | grep "db2jcc_license"`
		if [ ! -f "$DBMS_JDBC_LIB_PATH/db2jcc.jar" -o -z "$license_file" ];then
			getMessage TSIN01056E $DBMS_JDBC_LIB_PATH
	 		missing_info=$missing_info"\n$msg"
			#missing_info=$missing_info"\nOne or more required JDBC drivers not present under $DBMS_JDBC_LIB_PATH or not readable by the current user."
			getMessage TSIN01057E
	 		missing_info=$missing_info"\n$msg"
			#missing_info=$missing_info"\nSpecify the correct value for 'DBMS_JDBC_LIB_PATH'"
		fi

	fi
fi

if  [ "$DB_TYPE" = "ORACLE" ];then
	if [ "$db_dist" = "0" ];then
		if [ -z "$ORACLE_GROUP" ];then
			getMessage TSIN01060E
	 		missing_info=$missing_info"\n$msg"
        		#missing_info=$missing_info"\nThe value for 'ORACLE_GROUP' is empty"
		fi
	fi

	if  [ -z "$ORACLE_PORT_NUMBER" ];then
		getMessage TSIN01061E
	 	missing_info=$missing_info"\n$msg"
        	#missing_info=$missing_info"\nThe value for 'ORACLE_PORT_NUMBER' is empty"
	fi
fi
if  [ "$DB_TYPE" = "DB2" ];then
	if [ -z "$DB2_PORT_NUMBER" ];then
		getMessage TSIN01062E
	 	missing_info=$missing_info"\n$msg"
        	#missing_info=$missing_info"\nThe value for 'DB2_PORT_NUMBER' is empty"
	fi
	if  [ -z "$DB2_INSTANCE" ];then
		getMessage TSIN01064E
	 	missing_info=$missing_info"\n$msg"
        	#missing_info=$missing_info"\nThe value for 'DB2_INSTANCE' is empty"
	fi
fi

if  [ -z "$MQ_HOME" ];then
	getMessage TSIN01065E
	missing_info=$missing_info"\n$msg"
      	#missing_info=$missing_info"\nThe value for 'MQ_HOME' is empty"
fi
if [ -z "$MQ_USER" ];then
	 getMessage TSIN01070E
	 missing_info=$missing_info"\n$msg"
	#missing_info=$missing_info"\nThe value for 'MQ_USER' is empty"
fi
if [ -z "$MQ_USER_PASSWORD" ];then
	getMessage TSIN01071E
	missing_info=$missing_info"\n$msg"
	#missing_info=$missing_info"\nThe value for 'MQ_USER_PASSWORD' is empty"
fi
if [ -z "$MQ_QUEUE_MANAGER" ];then
	missing_info=$missing_info"\nThe value for 'MQ_QUEUE_MANAGER' is empty"
fi
if [ -n "$was_admin_user" ];then
	if [ -z "$WS_USER_1" ];then
		getMessage TSIN02011E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_USER_1' is empty"
	fi
	if [ -z "$WS_PWD_1" ];then
		getMessage TSIN02012E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_PWD_1' is empty"
	fi
	if [ -z "$WS_SSL_1" ];then
		getMessage TSIN02013E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_SSL_1' is empty"
	fi
	if [ -z "$WS_USER_2" ];then
		getMessage TSIN02014E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_USER_2' is empty"
	fi
	if [ -z "$WS_PWD_2" ];then
		getMessage TSIN02015E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_PWD_2' is empty"
	fi
	if [ -z "$WS_SSL_2" ];then
		getMessage TSIN02016E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_SSL_2' is empty"
	fi
	if [ -z "$WS_USER_3" ];then
		getMessage TSIN02017E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_USER_3' is empty"
	fi
	if [ -z "$WS_PWD_3" ];then
		getMessage TSIN02018E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_PWD_3' is empty"
	fi
	if [ -z "$WS_SSL_3" ];then
		getMessage TSIN02019E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_SSL_3' is empty"
	fi
	if [ -z "$WS_USER_4" ];then
		getMessage TSIN02020E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_USER_4' is empty"
	fi
	if [ -z "$WS_PWD_4" ];then
		getMessage TSIN02021E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_PWD_4' is empty"
	fi
	if [ -z "$WS_SSL_4" ];then
		getMessage TSIN02022E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_SSL_4' is empty"
	fi
	if [ -z "$WS_USER_5" ];then
		getMessage TSIN02023E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_USER_5' is empty"
	fi
	if [ -z "$WS_PWD_5" ];then
		getMessage TSIN02024E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_PWD_5' is empty"
	fi
	if [ -z "$WS_SSL_5" ];then
		getMessage TSIN02025E
		missing_info=$missing_info"\n$msg"
		#missing_info=$missing_info"\nThe value for 'WS_SSL_5' is empty"
	fi
fi

if [ -n "$missing_info" ];then
	getMessage TSIN01072I
	echo_msg "\n $msg"
	#echo_msg "\n Install >> Information Verification"
	echo_msg "--------------------------------------------------"
	getMessage TSIN01073E
	echo_msg "\n$msg"
	#echo_msg "\n Missing Information"
	echo_msg "$missing_info"
	getMessage TSIN01074E
	echo_msg "\n$msg"
	#echo_msg "\n Please add the missing info and/or correct the invalid info in setPedigreeEnv.sh file and the restart the install process."
	exit_install
fi
}


cleanUp(){
if [ -d "/tmp/epedigree" ];then
	rm -rf /tmp/epedigree
fi
if [ -f "/tmp/ePedigree.zip" ];then
	${RM} /tmp/ePedigree.zip
fi
}

HealthCheck(){
unset status
unset mqstatus
unset serverStatus
unset dbstatus
unset rfidstatus
unset cp

status=0
cp=$cp:/tmp/pedExtract/ts/lib/com.ibm.rfidic.pedigree.install.syscheck.jar:$WAS_HOME/lib/j2ee.jar:${TS_HOME}/lib/commons-logging.1.1.1.jar:${TS_HOME}/lib/commons-codec-1.3.jar:${TS_HOME}/lib/commons-httpclient-3.1.jar

# Checking Mq
distributed $PEDIGREE_MQ_HOST
mq_dist=$?
if [ "$mq_dist" = "0" ];then
	if [ "$OS" = "SunOS" ];then
		mqmngr=`$MQ_HOME/bin/dspmq -m ${MQ_QUEUE_MANAGER} | awk '{print($2)}' | awk -F"(" '{print($2)}'` >>/dev/null
	else
		mqmngr=`$MQ_HOME/bin/dspmq -m ${MQ_QUEUE_MANAGER} | awk '{print($2)}' | awk -F "(" '{print($2)}'` >>/dev/null
	fi
	if [ -z "$mqmngr" ];then
		status=1
		getMessage TSIN02027E
		echo_msg "\n$msg"
		#echo_msg "\nMQ - QUEUE MANAGER NOT AVAILABLE"
	elif [ "$mqmngr" = "Running)" ];then
		getMessage TSIN02028I
		echo_msg "\n$msg"
		#echo_msg "\nMQ - QUEUE MANAGER RUNNING"
	elif [ ! "$mqmngr" = "Running)" ];then
		echo "Restarting the queue manager ${MQ_QUEUE_MANAGER}"
		$MQ_HOME/bin/endmqm -w ${MQ_QUEUE_MANAGER}
		$MQ_HOME/bin/strmqm ${MQ_QUEUE_MANAGER}
		str=$?
		if [ "$str" -ne 0 ];then
			status=1
			echo_msg "\nMQ - QUEUE MANAGER NOT RUNNING"
		else
			getMessage TSIN02028I
			echo_msg "\n$msg"
			#echo_msg "\nMQ - QUEUE MANAGER RUNNING"
		fi
	fi
else
	mqstatus=0
	if [ "$OS" = "Linux" ];then
		MQ_RPMS="MQSeriesTXClient MQSeriesJava MQSeriesServer MQSeriesRuntime"
		for rpmname in ${MQ_RPMS[@]}
		do
			rpmval=`(rpm -qa | grep ${rpmname})`
			if [ "${rpmval}" = "" ];then
	      			mqstatus=1
				break
			fi
		done
	elif [ "$OS" = "AIX" ];then
		MQ_PKGS="mqm.base.runtime mqm.client.rte mqm.server.rte mqm.java.rte"
		pkg_all=`lslpp -L all | grep mqm`
		for pkg in ${MQ_PKGS[@]}
		do
			pkgval=`echo ${pkg_all} | grep ${pkg}`
			if [ "${pkgval}" = "" ];then
	      			mqstatus=1
				break
			fi
		done
	elif [ "$OS" = "SunOS" ];then
		if [ "$(pkginfo | grep mqm)" = "" ];then
			mqstatus=1
		fi
	fi

	if [ "$mqstatus" = "0" ];then
		getMessage TSIN01058I
		echo_msg "\n$msg"
		#echo_msg "\nMQ - INSTALLED"
	else
		getMessage TSIN01059E
		echo_msg "\n$msg"
		status=1
		#echo_msg "\nMQ - NOT INSTALLED"
	fi
fi

# Checking WAS
if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
	cred="-username ${was_admin_user} -password ${was_admin_password}"
else
	unset cred
fi
serverStatus=`${WAS_HOME}/bin/serverStatus.sh $SERVERNAME $cred -profileName $WAS_PROFILE`
present=`echo "$serverStatus" | grep "STARTED"`
status=$?
if [ $status = 0 ];then
	getMessage TSIN01075I
	echo_msg "\n$msg"
	#echo_msg "\nWAS - RUNNING"
else
	status=1
	getMessage TSIN01076E
	echo_msg "\n$msg"
	#echo_msg "\nWAS - NOT RUNNING"
fi

# Checking DB
unset JDBC
case "$DB_TYPE" in
DB2)
	cp=$cp:$DBMS_JDBC_LIB_PATH/db2jcc.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cu.jar
	JDBC="jdbc:db2://${PEDIGREE_DB_HOST}:${DB2_PORT_NUMBER}/${DB_NAME}"
	;;
ORACLE)
	cp=$cp:$DBMS_JDBC_LIB_PATH/ojdbc6.jar
	if [ -n "$DB_URL" ];then
		JDBC="$DB_URL"
	else
		JDBC="jdbc:oracle:thin:@${PEDIGREE_DB_HOST}:${ORACLE_PORT_NUMBER}:${DB_NAME}"
	fi
	;;
*)
	getMessage TSIN01100E
	echo_msg "\n$msg"
	#echo_msg "Invalid RDBMS type."
	exit_install
	;;
esac

${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.HealthCheck_DB ${DB_TYPE} ${JDBC} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PWD} >> $LOG 2>>$LOG
dbstatus=`echo $?`
if [ "${dbstatus}" = "0" ];then
	getMessage TSIN01077I
	echo_msg "\n$msg"
	#echo_msg "\nDB - RUNNING"
else
	status=1
	getMessage TSIN01078E
	echo_msg "\n$msg"
	#echo_msg "\nDB - NOT RUNNING"
fi
if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
	user="-user ${was_admin_user} -password ${was_admin_password}"
else
	user="-user _none"
fi

SSL_SETTINGS="-Djava.protocol.handler.pkgs=com.ibm.net.ssl.internal.www.protocol -Djavax.net.ssl.trustStore="$WAS_HOME/profiles/$WAS_PROFILE/etc/DummyClientTrustFile.jks" -Djavax.net.ssl.trustStorePassword=WebAS -Djavax.net.ssl.keyStore="$WAS_HOME/profiles/$WAS_PROFILE/etc/DummyClientTrustFile.jks" -Djavax.net.ssl.keyStorePassword=WebAS -Djavax.net.ssl.keyStoreType=JKS -Djavax.net.ssl.trustStoreType=JKS -Djavax.net.ssl.protocol=SSL"

${WAS_HOME}/java/bin/java -classpath $cp $SSL_SETTINGS com.ibm.rfidic.pedigree.install.syscheck.CheckRFIDICEndpoints $user -port $TS_APP_PORT -host $TS_HOST >> $LOG 2>>$LOG
rfidstatus=$?
if [ "$rfidstatus" = "0" ];then
	getMessage TSIN02031I
	echo_msg "\n$msg"	
	#echo_msg "\nInfoSphere Traceability Server - RUNNING"
else
	status=1
	getMessage TSIN02032E
	echo_msg "\n$msg"
	#echo_msg "\nInfoSphere Traceability Server - NOT RUNNING"
fi

if [ "$status" = "1" ];then
	if [ "$SILENT" = "Y" ];then
		getMessage TSIN01079E
		echo_msg "\n$msg"
		#echo_msg "\nOne or more pre-requisite software services might not be started. Start the service(s) and retry install."
		clearMsgFiles
		exit 1
	else
		refresh_HealthCheck
	fi
fi	
}

checkPrereqSW(){
getMessage TSIN01080I
echo_msg "\n$msg"
#echo_msg "\nVerifying WebSphere Application Server installation location and version..."
if [ ! -d $WAS_HOME ]; then
	clear
	getMessage TSIN01081E
	echo_msg "$msg"
	#echo_msg "Install >> Pre-requisite Check >> Failure"
	echo_msg "----------------------------------------------"
	getMessage TSIN01082E $WAS_HOME
	echo_msg "$msg"
	#echo_msg "WebSphere Application Server installation is not found in the location $WAS_HOME"
	getMessage TSIN01083E
	echo_msg "$msg"
	#echo_msg "Verify the WebSphere Application Server installation location and then restart the installation."
	exit_install 
fi

####### Check WAS version ############
wasVersionIsValid=$FALSE
version=`${WAS_HOME}/bin/versionInfo.sh | ${HEAD}26 | ${TAIL}1`
ver=`echo "$version" | awk '{print($2)}'`

if [ `echo $ver | ${AWK_PERIOD} '{print($1)}'` -eq 7 ];then
	if [ `echo $ver | ${AWK_PERIOD} '{print($2)}'` -eq 0 ];then
		if [ `echo $ver | ${AWK_PERIOD} '{print($3)}'` -eq 0 ];then
			if [ `echo $ver | ${AWK_PERIOD} '{print($4)}'` -ge 21 ];then
				wasVersionIsValid=$TRUE
			fi
		else
			wasVersionIsValid=$TRUE
		fi
	fi
fi

if [ "$wasVersionIsValid" = "$FALSE" ];then
		clear
		getMessage TSIN01081E
		echo_msg "$msg"
		#echo_msg "Install >> Pre-requisite Check >> Failure"
		echo_msg "----------------------------------------------"
		getMessage TSIN01084E
		echo_msg "$msg"
		#echo_msg "A supported version of WebSphere Application Server was not found at the location mentioned by you."
		getMessage TSIN01023E
		echo_msg "$msg"
		#echo_msg "See the web page on the hardware and software prerequisites for more details."
		getMessage TSIN01085E
		echo_msg "$msg"
		#echo_msg "Install a supported version of WebSphere Application Server and then restart the installation."
		exit_install
fi

getMessage TSIN01086I
echo_msg "$msg"
#echo_msg "WebSphere Application Server installation location and version verified."

distributed $PEDIGREE_MQ_HOST
mq_dist=$?
if [ "$mq_dist" = "0" ];then
getMessage TSIN01087I
echo_msg "\n$msg"
#echo_msg "\nVerifying WebSphere MQ installation location and version..."
if [ ! -d $MQ_HOME ]; then
	clear
	getMessage TSIN01081E
	echo_msg "$msg"
	#echo_msg "Install >> Pre-requisite Check >> Failure"
	echo_msg "----------------------------------------------"
	getMessage TSIN01088E $MQ_HOME
	echo_msg "$msg"
	#echo_msg "WebSphere MQ installation is not found in the location $MQ_HOME."
	getMessage TSIN01089E
	echo_msg "$msg"
	#echo_msg "Verify the WebSphere MQ installation location and then restart the installation."
	exit_install
fi

#######Check MQ Version ###########
# Supported version is 7.0.1.8 and later 7.0.1 releases.
mqVersionValid=$FALSE
MQversion=`${MQ_HOME}/bin/dspmqver | grep "Version" | awk '{print($2)}'`

if [ `echo $MQversion | ${AWK_PERIOD} '{print($1)}'` = "7" ];then
	if [ `echo $MQversion | ${AWK_PERIOD} '{print($2)}'` = "0" ];then
		if [ `echo $MQversion | ${AWK_PERIOD} '{print($3)}'` = "1" ];then
			if [ `echo $MQversion | ${AWK_PERIOD} '{print($4)}'` -ge 8 ];then
				mqVersionValid=$TRUE
			fi
		fi
	fi
fi

if [ "$mqVersionValid" = "$FALSE" ];then
	clear
	getMessage TSIN01081E
	echo_msg "$msg"
	#echo_msg "Install >> Pre-requisite Check >> Failure"
	echo_msg "----------------------------------------------"
	getMessage TSIN01090E
	echo_msg "$msg"
	#echo_msg "A supported version of WebSphere MQ was not found at the location mentioned by you."
	getMessage TSIN01023E
	echo_msg "$msg"
	#echo_msg "See the web page on the hardware and software prerequisites for more details. "
	getMessage TSIN01091E
	echo_msg "$msg"
	#echo_msg "Install a supported version of WebSphere MQ and then restart the installation."
	exit_install
fi

getMessage TSIN01093I
echo_msg "$msg"
#echo_msg "MQ installation location and version verified."
fi

distributed $PEDIGREE_DB_HOST
db_dist=$?
if [ "$db_dist" = "0" ];then
	getMessage TSIN01094I
	echo_msg "\n$msg"
	#echo_msg "\nVerifying Database installation location and version..."
else
	getMessage TSIN01095I
	echo_msg "\n$msg"
	#echo_msg "\nVerifying Database version..."
fi

#######Check DB Version ###########
dbVersionValid=$FALSE
case "$DB_TYPE" in
	"ORACLE") 
	   pedDBVersion
  	   if [ `echo $DBversion | ${AWK} '{print($1)}'` = "11" ];then
		if [ `echo $DBversion | ${AWK} '{print($2)}'` = "2" ];then
			dbVersionValid=$TRUE
	 	fi
			       
		if [ "$dbVersionValid" = "$FALSE" ];then
			clear
			getMessage TSIN01081E
			echo_msg "$msg"
			#echo_msg "Install >> Pre-requisite Check >> Failure"
			echo_msg "----------------------------------------------"
			getMessage TSIN01097E
			echo_msg "\n$msg"	
			#echo_msg "\nA supported version of Oracle Server was not found at the location mentioned by you."
			getMessage TSIN01023E
			echo_msg "$msg"
			#echo_msg "See the web page on the hardware and software prerequisites for more details."
			getMessage TSIN01098E
			echo_msg "$msg"
			#echo_msg "Install a supported version of database and then restart the installation."
			exit_install
		fi
            fi
	;;
	"DB2") 
	   pedDBVersion
 	   if [ `echo $DBversion | ${AWK_PERIOD} '{print($1)}'` = "v9" ];then
                if [ `echo $DBversion | ${AWK_PERIOD} '{print($2)}'` = "7" ];then
                    dbVersionValid=$TRUE
                fi
          fi              
            
	  if [ "$dbVersionValid" = "$FALSE" ];then
		clear
		getMessage TSIN01081E
		echo_msg "$msg"
		#echo_msg "Install >> Pre-requisite Check >> Failure"
		echo_msg "----------------------------------------------"
		getMessage TSIN01099E
		echo_msg "$msg"
		#echo_msg "A supported version of DB2 Server was not found at the location mentioned by you."
		getMessage TSIN01023E
		echo_msg "$msg"
		#echo_msg "See the web page on the hardware and software prerequisites for more details."
		getMessage TSIN01098E
		echo_msg "$msg"
		#echo_msg "Install a supported version of database and then restart the installation."
		exit_install
       	   fi
	;;
	*) 
	   clear
	   getMessage TSIN01081E
	   echo_msg "$msg"
	   #echo_msg "Install >> Pre-requisite Check >> Failure"
	   echo_msg "----------------------------------------------"
	   getMessage TSIN01100E
	   echo_msg "\n$msg"
	   #echo_msg "\nInvalid database type specified."
	   getMessage TSIN01098E
	   echo_msg "$msg"
	   #echo_msg "Install a supported version of database and then restart the installation."
	   exit_install
	;;
esac

if [ "$db_dist" = "0" ];then
	getMessage TSIN01101I
	echo_msg "$msg"
	#echo_msg "Database installation location and version verified."
else
	getMessage TSIN01102I
	echo_msg "$msg"
	#echo_msg "Database version verified."
fi

}

installPedigree(){

	if [ -f "${PEDIGREE_HOME}/features/pedigree" ]; then
	  while [ 1 ];do
		if [ "$FORCE_INSTALL" != "Y" -a "$FORCE_INSTALL" != "y" ];then
			getMessage TSIN02033E $PEDIGREE_HOME
			echo_msg "$msg"
	  		#echo_msg "The pedigree installation directory $PEDIGREE_HOME is not empty."
			getMessage TSIN02034W $PEDIGREE_HOME
			echo_msg "$msg"
			#echo_msg "Do you want to remove the contents of this directory and continue installation of ePedigree under $PEDIGREE_HOME (y/n)?"
			read answer
			answer=`echo "$answer" | tr "[a-z]" "[A-Z]"`
		else
			answer="Y"
		fi
		if [ "$answer" = "Y" ];then
			break
		elif [ "$answer" = "N" ];then
			exit_install
		else
			getMessage TSIN01011E 
			echo_msg "$msg"
			#echo_msg "Invalid input. Try again."
		fi
	   done
	fi

	# Extract the files from the build
	getMessage TSIN02035I 
	echo_msg "$msg"
	#echo_msg "${0}: Extracting PEDIGREE files..."
	run_command unzip ePedigree.zip -d ${WAS_HOME} >>/dev/null
        if [ $? -ne 0 ]; then 
          exit_install
        fi	


	if [ ! -f "${PEDIGREE_HOME}/features/pedigree" ]; then
		mkdir  -p "${PEDIGREE_HOME}/features/pedigree"
	fi
	
	updatePedEnv
	updateInstPedXML
	
	changeOwnership

	run_command cp -f ${PEDIGREE_HOME}/reserved/pedigree.xml ${TS_HOME}/features/pedigree/
	run_command cp -f ${PEDIGREE_HOME}/etc/pedigreeLog.properties ${TS_HOME}/features/pedigree/
	run_command cp -f ${PEDIGREE_HOME}/etc/fop.xconf ${TS_HOME}/features/pedigree/
	clear
	getMessage TSIN01109I 
	echo_msg "$msg"
	#echo_msg "Install>> Installing Binaries"
	echo_msg "--------------------------------------------------"
	getMessage TSIN02037I 
	echo_msg "\n$msg"
	#echo_msg "\nInstallation of ePedigree binaries succeeded.\n"
}

changeOwnership(){
	
	# Change ownership of files
	getMessage TSIN01108I
	echo $msg
	#echo "Setting file permissions"
	
	run_command chmod -R 755 ${PEDIGREE_HOME}/features

	# the contents of directories MEDATA, log, tsar, and tempMessageRepository must be writable.
	run_command find ${PEDIGREE_HOME} \( -name MEDATA -o -name logs  -o -name tempMessageRepository -o -name tsar \) -prune -o -type f -exec chmod 444 {} \;

	run_command chmod 644 ${PEDIGREE_HOME}/etc/fop.xconf
	run_command chmod 644 ${PEDIGREE_HOME}/etc/pedigreeLog.properties

	run_command find ${PEDIGREE_HOME} -name logs -prune -o -name "*.sh" -exec chmod 755 {} \;

	run_command chmod 644 ${PEDIGREE_HOME}/bin/*.xml
	# private key is private
	run_command chmod 600 ${PEDIGREE_HOME}/bin/sfrks.jks
	run_command chmod 644 ${PEDIGREE_HOME}/bin/migration.properties
	run_command chmod 644 ${PEDIGREE_HOME}/features/pedigree/pedigree.xml
	# if there are existing pedigree log files they need to be writeable.
	ls ${PEDIGREE_HOME}/features/pedigree/pedigree.log* >/dev/null 2>&1 && run_command chmod 600 ${PEDIGREE_HOME}/features/pedigree/pedigree.log*

	run_command chmod 644 ${PEDIGREE_HOME}/../installableApps/com.ibm.epcis.pharma.pedigree.ear
	run_command chmod 644 ${PEDIGREE_HOME}/../installableApps/com.ibm.rfidic.pharma.epedigree.ui.ear
	run_command chmod 644 ${PEDIGREE_HOME}/../installableApps/DocumentPedigree.ear
	
	getMessage TSIN02261I
	echo $msg
	#echo $file permissions set
}

updateInstPedXML(){
	# Update DB properties in pedigree.xml
        # TODO: defaults should not be informix
	searchStr[0]='property name="sqlFlavor" value="informix"'
	searchStr[1]='property name="driverClassName" value="com.informix.jdbc.IfxDriver"'
	searchStr[2]='value="jdbc:informix-sqli://localhost:1526/pedigree:INFORMIXSERVER=IBMIFX_DSv11"'
	searchStr[3]='property name="user" value="rfidic"'
	searchStr[4]='property name="password" value="$password"'

	replaceStr[0]="property name=\"sqlFlavor\" value=\"$DB_TYPE\""
	replaceStr[1]="property name=\"driverClassName\" value=\"$DRIVER_CLASS\""
	replaceStr[2]="value=\"$JDBC_URL\""
	replaceStr[3]="property name=\"user\" value=\"$DBMS_ADMIN_USER\""
	replaceStr[4]="property name=\"password\" value=\"$DBMS_ADMIN_PWD\""
	asciiUpdate "$PEDIGREE_HOME/reserved/pedigree.xml" "$searchStr" "$replaceStr"

	# Update TS hostname and port info
	asciiUpdate "$PEDIGREE_HOME/reserved/pedigree.xml" 'http://localhost:9080' "http://${TS_HOST}:${TS_APP_PORT}"

	# Update TS hostname, port number and user info for secured TS
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
	        searchStr[0]='https://localhost:9443'
		searchStr[1]='property name="userid" value="rfidic"'
		searchStr[2]='property name="password" value="rfidic"'

		replaceStr[0]="https://${TS_HOST}:${TS_APP_PORT}"
		replaceStr[1]="property name=\"userid\" value=\"${was_admin_user}\""
		replaceStr[2]="property name=\"password\" value=\"${was_admin_password}\""

		asciiUpdate "$PEDIGREE_HOME/reserved/pedigree.xml" "$searchStr" "$replaceStr"
	fi 
	

	# Update MQ information 
	searchStr[0]='property name="QUEUE_MANAGER_NAME" value="TS.QUEUE.MANAGER"'
	searchStr[1]='property name="QUEUE_NAME" value="EPCEVENT"'
	searchStr[2]='property name="HOST_NAME" value="MQSYSTEMNAME"'
	searchStr[3]='property name="MQ_LISTENER_PORT"><value type="int">1414'

	replaceStr[0]="property name=\"QUEUE_MANAGER_NAME\" value=\"$MQ_QUEUE_MANAGER\""
	replaceStr[1]="property name=\"QUEUE_NAME\" value=\"$QUEUE_NAME\""
	replaceStr[2]="property name=\"HOST_NAME\" value=\"$PEDIGREE_MQ_HOST\""
	replaceStr[3]="property name=\"MQ_LISTENER_PORT\"><value type=\"int\">$MQ_LSR_PORT"		
	asciiUpdate "$PEDIGREE_HOME/reserved/pedigree.xml" "$searchStr" "$replaceStr"
		
	#Exporting the PEDIGREE_HOME value
	eval TS_ADMIN_HOME=~"${TS_ADMIN_USER}"
	grep "PEDIGREE_HOME" $TS_ADMIN_HOME/$RFIDIC_PROFILE
	if [ "$?" -ne "0" ];then
		echo "PEDIGREE_HOME=$PEDIGREE_HOME" >> ${TS_ADMIN_HOME}/${RFIDIC_PROFILE}
		echo "export PEDIGREE_HOME" >> ${TS_ADMIN_HOME}/${RFIDIC_PROFILE}
	fi

	asciiUpdate "$PEDIGREE_HOME/reserved/pedigree.xml" '${repository_backup_dir}' "${PEDIGREE_HOME}/repository"
	asciiUpdate "$PEDIGREE_HOME/reserved/pedigree.xml" 'property name="FAILED_DOCUMENT_DIR" value=""' "property name=\"FAILED_DOCUMENT_DIR\" value=\"${PEDIGREE_HOME}/repository\""

	# Update properties in samples

	# Update DB properties in SAMPLE pedigree.xml
        #TODO defaults should not be informix
	searchStr[0]='property name="sqlFlavor" value="informix"'
	searchStr[1]='property name="driverClassName" value="com.informix.jdbc.IfxDriver"'
	searchStr[2]='value="jdbc:informix-sqli://localhost:1526/pedigree:INFORMIXSERVER=IBMIFX_DSv11"'
	searchStr[3]='property name="user" value="rfidic"'
	searchStr[4]='property name="password" value="$password"'

	replaceStr[0]="property name=\"sqlFlavor\" value=\"$DB_TYPE\""
	replaceStr[1]="property name=\"driverClassName\" value=\"$DRIVER_CLASS\""
	replaceStr[2]="value=\"$JDBC_URL\""
	replaceStr[3]="property name=\"user\" value=\"$DBMS_ADMIN_USER\""
	replaceStr[4]="property name=\"password\" value=\"$DBMS_ADMIN_PWD\""
	asciiUpdate "$PEDIGREE_HOME/samples/epedigree/etc/pedigree.xml" "$searchStr" "$replaceStr"

	# Update TS hostname and port info
	asciiUpdate "$PEDIGREE_HOME/samples/epedigree/etc/pedigree.xml" 'http://localhost:9080' "http://${TS_HOST}:${TS_APP_PORT}"

	# Update TS hostname, port number and user info for secured TS
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
		searchStr[0]='https://localhost:9443'
		searchStr[1]='property name="userid" value="rfidic"'
		searchStr[2]='property name="password" value="rfidic"'

		replaceStr[0]="https://${TS_HOST}:${TS_APP_PORT}"
		replaceStr[1]="property name=\"userid\" value=\"${was_admin_user}\""
		replaceStr[2]="property name=\"password\" value=\"${was_admin_password}\""

		asciiUpdate "$PEDIGREE_HOME/samples/epedigree/etc/pedigree.xml" "$searchStr" "$replaceStr"
    		asciiUpdate "$PEDIGREE_HOME/samples/epedigree/etc/pedigree.xml" '/opt/ibm/InfoSphere/EPedigree/' "$PEDIGREE_HOME/"
	fi

	# Update MQ information in SAMPLE pedigree.xml
	searchStr[0]='property name="QUEUE_MANAGER_NAME" value="TS.QUEUE.MANAGER"'
	searchStr[1]='property name="QUEUE_NAME" value="EPCEVENT"'
	searchStr[2]='property name="HOST_NAME" value="MQSYSTEMNAME"'
	searchStr[3]='property name="MQ_LISTENER_PORT"><value type="int">1414'

	replaceStr[0]="property name=\"QUEUE_MANAGER_NAME\" value=\"$MQ_QUEUE_MANAGER\""
	replaceStr[1]="property name=\"QUEUE_NAME\" value=\"$QUEUE_NAME\""
	replaceStr[2]="property name=\"HOST_NAME\" value=\"$PEDIGREE_MQ_HOST\""
	replaceStr[3]="property name=\"MQ_LISTENER_PORT\"><value type=\"int\">$MQ_LSR_PORT"		
	asciiUpdate "$PEDIGREE_HOME/samples/epedigree/etc/pedigree.xml" "$searchStr" "$replaceStr"

	#
	# Application configuration files
	#
	if [ ! -d "${TS_HOME}/features/pedigree" ];then
		mkdir -p ${TS_HOME}/features/pedigree
	fi

}

configureDocPed(){
unset DBMS_DB_NAME;unset DBMS_HOME;unset DBMS_ADMIN_USER;unset DBMS_ADMIN_PWD;unset DB_TYPE;unset DBMS_PORT;unset DBMS_SERVER
unset WAS_HOME;unset PROFILENAME;unset CELLNAME;unset NODENAME;unset SERVERNAME
unset MQ_HOME;unset QUEUE_MANAGER;unset MQ_LSR_PORT;unset MQ_USER

unset retStatus
retStatus=0

. $PEDIGREE_HOME/bin/pedigree-env.sh >>/dev/null

getMessage TSIN02038I 
echo_msg "\n$msg"
#echo_msg "\nConfiguring resources for document pedigree..."
if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
fi		
if [ -n "$was_runas_user" ];then
	 was_runas="-was_runas_user=$was_runas_user"
fi
if [ -z "$PEDIGREE_HOME" ];then
	while [ 1 ];do
		getMessage TSIN02039I
		echo_msg "$msg"
		#echo_msg "Enter the install location of event pedigree."
		read ans
		if [ -f $ans"/reserved/pedigree.xml" ];then
			PEDIGREE_HOME="`( cd \"${ans}""\" && pwd )`"
			PEDIGREE_HOME="`cd \"$PEDIGREE_HOME\" 2>/dev/null && pwd || echo \"$PEDIGREE_HOME\"`"
			$ECHO "PEDIGREE_HOME=${PEDIGREE_HOME}"
			break
		fi
	done
fi
if [ -z "$CAPTURE_TYPE" ];then
	while [ 1 ];do
		getMessage TSIN02040I
		echo_msg "$msg"
		#echo_msg "Enter the capture type for document pedigree. Valid values are 'HTTP' and 'MQ'."
		read ans
		if [ "$ans" = "HTTP" -o "$ans" = "MQ" ];then
			asciiUpdate "$PEDIGREE_HOME/bin/pedigree-env.sh" 'CAPTURE_TYPE=HTTP' "CAPTURE_TYPE=$ans"
			break
		fi
	done
fi


# Create repository directory
if [ ! -d "${PEDIGREE_HOME}/repository" ];then
	mkdir ${PEDIGREE_HOME}/repository
	chmod 777 ${PEDIGREE_HOME}/repository
fi
# Recreate the solution schemas in pedigree
getMessage TSIN02041I
echo_msg "$msg"
#echo_msg "Configuring the database for document pedigree..."
getDBConfig
replaceStorageOptions ${docped_file}
${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${docped_file} >> $LOG 2>>$LOG
ret=$?
if [ $ret -ne 0 ];then
	getMessage TSIN02042E 
	echo_msg "$msg"
	#echo_msg "\nConfiguration of database for document pedigree not successful."
	retStatus=1
fi
echo_message PEDI06807I >> $LOG

	if [ "$dba_user" = "$DBMS_ADMIN_USER" ];then
		getMessage TSIN02043I 
		echo_msg "$msg"
		#echo_msg "DBA User entered is the same as database user. Hence not granting privileges"
	else
		searchStr[0]='${non_dba_user}'
		replaceStr[0]="$DBMS_ADMIN_USER"
		asciiUpdate "$grant_docPed_priv_file" "$searchStr" "$replaceStr"
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${grant_docPed_priv_file}>> $LOG 2>>$LOG
		ret=$?
		if [ $ret -ne 0 ];then
			getMessage TSIN02044E
			echo_msg "\n$msg"
			#echo_msg "\nConfiguration of pedigree database for non-DBA - docPed-rights not successful."
			retStatus=1
		fi
	fi

# MQ Configuration
getMessage TSIN02045I 
echo_msg "$msg"
#echo_msg "Configuring WebSphere MQ for document pedigree..."
${PEDIGREE_HOME}/bin/pedigree-mq-cfg.sh -docped
ret=$?
if [ $ret -ne 0 ];then
	getMessage TSIN02046E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration of MQ resources for document pedigree not successful."
	retStatus=1
fi

# WAS Configuration
getMessage TSIN02047I
echo_msg "$msg"
#echo_msg "Configuring WebSphere Application Server for document pedigree..."

${PEDIGREE_HOME}/bin/pedigree-was-cfg.sh -docped $credentials $was_runas
ret=$?
if [ $ret -ne 0 ];then
	getMessage TSIN02048E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration of WAS resources for document pedigree not successful."
	retStatus=1
fi
if [ "$retStatus" = "0" ];then
	getMessage TSIN02049I
	echo_msg "\n$msg"
	#echo_msg "\nResources for document pedigree configured successfully."
else
	getMessage TSIN02050E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration of resources for document pedigree not successful."
fi
return $retStatus
}

configureEped(){
unset DBMS_DB_NAME;unset DBMS_HOME;unset DBMS_ADMIN_USER;unset DBMS_ADMIN_PWD;unset DB_TYPE;unset DBMS_PORT;unset DBMS_SERVER
unset WAS_HOME;unset PROFILENAME;unset CELLNAME;unset NODENAME;unset SERVERNAME
unset MQ_HOME;unset QUEUE_MANAGER;unset MQ_LSR_PORT;unset MQ_USER

unset retStatus
retStatus=0
. ${PEDIGREE_HOME}/bin/pedigree-env.sh >>/dev/null
setVars
getMessage TSIN02051I
echo_msg "\n$msg"
#echo_msg "\nConfiguring resources for event pedigree..."


# Recreate the solution schemas in pedigree
getMessage TSIN02052I 
echo_msg "$msg"
#echo_msg "Configuring the database for event pedigree..."
getDBConfig
replaceStorageOptions ${trace_file} 
${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${trace_file} >> $LOG 2>>$LOG
ret=$?
if [ $ret -ne 0 ];then
	getMessage TSIN02053E
	echo_msg "$msg"
	#echo_msg "\nConfiguration of database for event pedigree not successful."
	retStatus=1
fi

	if [ "$dba_user" = "$DBMS_ADMIN_USER" ];then
		getMessage TSIN02054I
		echo_msg "$msg"
		#echo_msg "DBA User entered is the same as database user. Hence not granting privileges (trace)"
	else
		searchStr[0]='${non_dba_user}'
		replaceStr[0]="$DBMS_ADMIN_USER"
		asciiUpdate "$grant_trace_priv_file" "$searchStr" "$replaceStr"
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${grant_trace_priv_file}>> $LOG 2>>$LOG
		ret=$?
		if [ $ret -ne 0 ];then
			getMessage TSIN02055E 
			echo_msg "\n$msg"
			#echo_msg "\nConfiguration of pedigree database for non-DBA rights - trace- not successful."
			retStatus=1
		fi
	fi

#replaceStorageOptions $msg_file
${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${msg_file} >> $LOG 2>>$LOG
ret=$?
if [ $ret -ne 0 ];then
	getMessage TSIN02053E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration of database for event pedigree not successful."
	retStatus=1
fi
echo_message PEDI06807I >> $LOG

# deploying the TS feature 'ePedigree'
	getMessage TSIN02057I
	echo_msg "$msg"
	#echo_msg "Pedigree on top of IBM InfoSphere Traceability Server system"
	unset DBMS_DB_NAME;unset DBMS_HOME;unset DBMS_ADMIN_USER;unset DBMS_ADMIN_PWD;unset DB_TYPE;unset DBMS_PORT;unset DBMS_SERVER
        . ${TS_HOME}/bin/tsEnv.sh >>/dev/null
        unset JDBC;unset driverClassName;unset file;unset JDBC_HOME;unset cp
	
	cp=${PEDIGREE_HOME}/lib/com.ibm.rfidic.pedigree.install.syscheck.jar:${TS_HOME}/lib/commons-dbutils-1.1.jar
	JDBC_HOME="${DBMS_JDBC_LIB_PATH}"

	# Recreate the audit schemas
    if [ "$DB_TYPE" = "ORACLE" ];then
		driverClassName="oracle.jdbc.OracleDriver"
		JDBC="jdbc:oracle:thin:@${TS_DB_HOST}:${ORACLE_PORT_NUMBER}:${DBMS_DB_NAME}"
		file="${PEDIGREE_HOME}/bin/Oracle/recreateAuditviews.sql"
		cp=$cp:${JDBC_HOME}/ojdbc6.jar
	elif [ "$DB_TYPE" = "DB2" ];then
		driverClassName="com.ibm.db2.jcc.DB2Driver"
		JDBC="jdbc:db2://${TS_DB_HOST}:${DB2_PORT_NUMBER}/${DBMS_DB_NAME}"
		file="${PEDIGREE_HOME}/bin/DB2/recreateAuditviews.sql"
		cp=$cp:${JDBC_HOME}/db2jcc.jar:${JDBC_HOME}/db2jcc_license_cu.jar
	fi

	#replaceStorageOptions "$file"
	${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${file} >> $LOG 2>>$LOG
	ret=$?
	if [ $ret -ne 0 ];then
		getMessage TSIN02053E
		echo_msg "\n $msg"
		#echo_msg "\n Configuration of database for event pedigree not successful."
		retStatus=1
	fi
	
	unset JDBC;unset driverClassName;unset file;unset JDBC_HOME;unset cp
	unset DBMS_DB_NAME;unset DBMS_HOME;unset DBMS_ADMIN_USER;unset DBMS_ADMIN_PWD;unset DB_TYPE;unset DBMS_PORT;unset DBMS_SERVER
	unset WAS_HOME;unset PROFILENAME;unset CELLNAME;unset NODENAME;unset SERVERNAME
	unset MQ_HOME;unset QUEUE_MANAGER;unset MQ_LSR_PORT;unset MQ_USER

	. ${PEDIGREE_HOME}/bin/pedigree-env.sh >>/dev/null

# MQ 
getMessage TSIN02060I
echo_msg "$msg"
#echo_msg "Configuring WebSphere MQ for event pedigree..."
${PEDIGREE_HOME}/bin/pedigree-mq-cfg.sh
ret=$?
if [ $ret -ne 0 ];then
	getMessage TSIN02061E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration of MQ resources for event pedigree not successful."
	retStatus=1
fi

# WAS
getMessage TSIN02062I
echo_msg "$msg"

#echo_msg "Configuring WebSphere Application Server for event pedigree..."
${PEDIGREE_HOME}/bin/pedigree-was-cfg.sh $credentials $was_runas
ret=$?
if [ $ret -ne 0 ];then
	getMessage TSIN02063E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration of WAS resources for event pedigree not successful."
	retStatus=1
fi

if [ "$retStatus" = "0" ];then
	getMessage TSIN02064I
	echo_msg "\n$msg"
	#echo_msg "\nResources for event pedigree configured successfully."
else
	getMessage TSIN02065E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration of resources for event pedigree not successful."
fi

return $retStatus
}

#### Main function
main(){

# Check for TS_HOME first. If TS_HOME exists then source tsEnv.sh. 
if [ -n "$TS_HOME" ];then
	if [ ! -f "$TS_HOME/bin/tsEnv.sh" ]; then
		getMessage TSIN02071E $TS_HOME
  		echo_msg "$msg"
		#echo_msg "Cannot find $TS_HOME/bin/tsEnv.sh."
		getMessage TSIN02072E
  		echo_msg "$msg"
		echo_msg "Ensure that the IBM InfoSphere Traceability Server installation directory is correct and retry install."
		exit_install
	else
		if [ -z "$TS_HOST" ]; then
			TS_HOST=$HOSTNAMEFULL
		fi

		DB_TABLE_SPACE=$DB_TABLE_SPACE

		# source tsEnv.sh
		. ${TS_HOME}/bin/tsEnv.sh
		
		PEDIGREE_HOME=$TS_HOME
		MQ_QUEUE_MANAGER=$QUEUE_MANAGER
		PEDIGREE_DB_HOST=${DBMS_HOST}
		PEDIGREE_MQ_HOST=${MQ_HOST}
		TS_APP_PORT=${WAS_PORT_NO}		
		DB_NAME=$DBMS_DB_NAME
		rfidic_user_password=$ts_admin_password
		
		if [ "$DB_TYPE" = "ORACLE" ];then
			DB_URL=$ORACLE_JDBC_URL
		fi
		
		TS_TABLE_SPACE=`cat $TS_HOME/etc/RFIDICServer.xml | grep "<DBTableSpace>" | ${AWK_BRACE1} '{print($2)}' | ${AWK_BRACE2} '{print($1)}'`
		if [ -n "$TS_TABLE_SPACE" ]; then
			DB_TABLE_SPACE=$TS_TABLE_SPACE
		fi
		
	fi
else
		echo "TS_HOME is not set"
		getMessage TSIN02072E
  		echo_msg "$msg"
		echo_msg "Ensure that the IBM InfoSphere Traceability Server installation directory is correct and retry install."
		exit_install
fi


distributed $PEDIGREE_DB_HOST
db_dist=$?

if [ -z "$DBMS_ADMIN_USER" ];then
	DBMS_ADMIN_USER=$dba_user
fi

if [ -z "$DBMS_ADMIN_PWD" ];then
	DBMS_ADMIN_PWD=$dba_password
fi

if [ -z "$DB2_PORT_NUMBER" ];then
	DB2_PORT_NUMBER=$DBMS_PORT_NUMBER
fi

if [ -z "$ORACLE_PORT_NUMBER" ];then
	ORACLE_PORT_NUMBER=$DBMS_PORT_NUMBER
fi

if [ -z "$DBMS_JDBC_LIB_PATH" ];then
	if [ "$db_dist" = "0" ];then
		if [ -n "$DBMS_HOME" ];then
			if [ "$DB_TYPE" = "ORACLE" ];then
				DBMS_JDBC_LIB_PATH=$DBMS_HOME/jdbc/lib
			elif [ "$DB_TYPE" = "DB2" ];then
				DBMS_JDBC_LIB_PATH=$DBMS_HOME/java
			fi
		fi
	fi
fi

if [ -z "$TS_DB_HOST" ];then
	TS_DB_HOST=$DBMS_HOST
fi
if [ -z "$Document_capture_bus" ];then
	Document_capture_bus=DocPedigreeCaptureBus
fi
if [ -z "$Document_service_bus" ];then
	Document_service_bus=DocPedigreeServiceBus
fi
if [ -z "$DOCPEDIGREE_QUEUE" ];then
	DOCPEDIGREE_QUEUE=DOCUMENTQUEUE
fi
if [ -z "$QNAME_PEDIGREE_EVENT" ];then
	QNAME_PEDIGREE_EVENT=PedigreeEventIn
fi
if [ -z "$MDM_CHANGE_NOTIF_QUEUE_NAME" ];then
	MDM_CHANGE_NOTIF_QUEUE_NAME=MDMChangeNotification
fi
if [ -z "$was_runas_user" ];then
	was_user=$CURRENT_USER
else
	was_user=$was_runas_user
fi
if  [ -z "$MQ_LSR_PORT" ];then
        MQ_LSR_PORT=1414
fi

#### Set default values ##############################
if [ -z "$WAS_PROFILE" ];then
		WAS_PROFILE=AppSrv01
fi
if [ -z "$SERVERNAME" ];then
	SERVERNAME=server1
fi
if [ -z "$NODENAME" ];then
	NODENAME="$HOSTNAME"Node01
fi
if [ -z "$CELLNAME" ];then
	CELLNAME="$HOSTNAME"Node01Cell
fi


	if [ "$SILENT" = "Y" ];then
		if  [ -z "$dba_user" -o -z "$dba_password" ];then
			getMessage TSIN02074W
			echo_msg "$msg"
			#echo_msg "Pedigree dba_user and/or dba_password is not passed as arguments."
			usage
			clearMsgFiles
			exit 1
		fi
	else
		promptDBAUser
        fi


if [ ! "$SILENT" = "Y" ];then
	clear
	getMessage TSIN01122I
  	echo_msg "$msg"
	#echo_msg "Install >> Platform Verification"
	echo_msg "-------------------------------------------------------"
	prereqCheck
	pause
	missingInfo
	displaySummary
	clear
	getMessage TSIN01123I
  	echo_msg "$msg"
	#echo_msg "Install >> Prerequisite software verification"
	echo_msg "-------------------------------------------------------"
	checkPrereqSW
	pause
	clear
	getMessage TSIN01124I
  	echo_msg "$msg"
	#echo_msg "Install>> Prerequisite software verification >> Health Check"
	echo_msg "-------------------------------------------------------------"
	HealthCheck
	pause
	clear
	getMessage TSIN01125I
  	echo_msg "$msg"
	#echo_msg "Install>> Installing Binaries"
	echo_msg "--------------------------------------------------"
	installPedigree
	pause
	getMessage TSIN02075I
  	echo_msg "$msg"
	#echo_msg "Install>> Configuration"
	echo_msg "--------------------------------------------------"
	getMessage TSIN02076I 
  	echo_msg "$msg"
	#echo_msg "\n\nIn order to use ePedigree you need to configure resources for WAS, MQ and database."
	getMessage TSIN01132I
  	echo_msg "\n\n$msg"
	#echo_msg "\n\nNote: You can choose to come back and continue with this step later."
	continueOrExit
	clear
	getMessage TSIN02075I
  	echo_msg "$msg"
	#echo_msg "Install >> Configuration"
	echo_msg "----------------------------------------------"
else
	prereqCheck
	missingInfo
	checkPrereqSW
	HealthCheck
	installPedigree
fi

configureEped
epedStat=$?

clear
configureDocPed
docStat=$?
unset stat
stat=0
SILENT="N"
clear
getMessage TSIN01136I 
echo_msg "$msg"
#echo_msg "Install >> Success"
echo_msg "------------------------------------------------------"
getMessage TSIN02077I $PEDIGREE_HOME
echo_msg "$msg"
#echo_msg "\nePedigree has been successfully installed under $PEDIGREE_HOME."
if [ "$epedStat" = "0" ];then
	getMessage TSIN02078I
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration SUCCESSFUL: Event Pedigree"
else
	stat=1
	getMessage TSIN02079E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration NOT SUCCESSFUL: Event Pedigree"
fi
if [ "$docStat" = "0" ];then
	getMessage TSIN02080I
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration SUCCESSFUL: Document Pedigree"
else
	stat=1
	getMessage TSIN02081E
	echo_msg "\n$msg"
	#echo_msg "\nConfiguration NOT SUCCESSFUL: Document Pedigree"
fi
if [ $stat -eq 1 ];then
	getMessage TSIN01144E $LOG
	echo_msg "\n$msg"
	#echo_msg "\nThe failure information can be found in the log file $LOG."
fi
clearMsgFiles
exit 0
}

#### Input Arguments Verification #####
unset configure_only
for item in $*
do
	if [ `expr match "$item" '-configure_only'` != 0 ];then
              configure_only=true
	elif [ `expr match "$item" '-log'` != 0 ];then
              LOG=`echo ${item#-log=}`    
	elif [ `expr match "$item" '-dba_user'` != 0 ];then
              dba_user=`echo ${item#-dba_user=}`    
	elif [ `expr match "$item" '-dba_password'` != 0 ];then
              dba_password=`echo ${item#-dba_password=}`    
	else
            usage
      fi
done
cleanUp
SILENT=`echo "$SILENT" | tr "[a-z]" "[A-Z]"`

assignLogFile epedigree-install

if [ -f ${scriptDir}/setPedigreeEnv.sh ]; then
	. ${scriptDir}/setPedigreeEnv.sh
else
	clear
	echo_msg "Install >> Error"
	echo_msg "--------------------------------------------------"
	echo_msg "\nCould not find setPedigreeEnv.sh in $scriptDir. Ensure that the file is in the same directory as the install script and retry install."
	echo_msg "\nVerify setPedigreeEnv.sh is in the directory $scriptDir and retry."
	exit
fi
if  [ -z "$PEDIGREE_BUILD_PATH" ];then
       PEDIGREE_BUILD_PATH=${scriptDir}/ePedigree.zip
fi
if [ ! -f "$PEDIGREE_BUILD_PATH" ]; then
	echo_msg "Install >> Error"
	echo_msg "--------------------------------------------------"
	echo_msg "\n\nCould not find the epedigree tar file in $PEDIGREE_BUILD_PATH. Ensure that the path of the file is correct and retry install."
	exit
fi

copyMsgFiles $PEDIGREE_BUILD_PATH

if [ "$configure_only" = "true" ];then
	clear
	. ${TS_HOME}/bin/pedigree-env.sh >>/dev/null
	echo_msg "Install >> Configuration"
	echo_msg "----------------------------------------------"
	if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
		getMessage TSIN01153I $was_admin_user
  		echo_msg "$msg"
      		#echo_msg "Enter the password for the WAS Administrative user: $was_admin_user"
		stty -echo
		read was_admin_password
		stty echo
		echo
	fi

	if [ "$DB_TYPE" != "INFORMIX" ];then
		promptDBAUser
	fi
	configureEped
	configureDocPed
	echo_msg "\nFor more information, see the log file $LOG."
	clearMsgFiles
	exit 0
fi
displayLA ${PEDIGREE_BUILD_PATH}
install=true
main
clearMsgFiles
exit 0
