#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2008
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: setWebServicesBindingInfo.sh	
##   Description: Sets the binding information for the Web Services
##   Usage: Options:See usage() method below
##
#############################################################################

#
# setup solution environment
#
SCRIPT_DIR=`dirname ${0}`
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
	. ${SCRIPT_DIR}/pedigree-env.sh
else
	#"$0 : File not found ${SCRIPT_DIR}/pedigree-env.sh"
	exit 1
fi

usage()
{
  usage="\n\
  $0 '[options]'\n\
  Options:\n\
  -user   	  User to be set in Web Services Binding information \n\
  -password     Password for the above use \n\
  -was_admin_user optional argment if WAS is security enabled \n\
  -was_admin_password optional argment if was_admin_user needs to be passed \n\
  -help prints the usage\n\
  -APP_NAME The ear name\n\
  -APP_MODULE The war or ejb jar name\n\
  -APP_EJB The EJB name if APP_MODULE is an ejb jar file\n\
  -APP_SERVICE - The relative service url\n\
  -APP_PORT - Port\n\
  -APP_EPU - New End Point URL\n\
  -timeout - timeout on the client web services binding\n\
  -SSL_CONFIG - SSL Configuration name for Internal Web Services Security\n"
  echo -e "Usage: $usage"
  return 0
}

unset was_admin_user
unset was_admin_password
unset user
unset password

for item in $*
do
	if [ `expr match "$item" '-was_admin_user'` != 0 ]; then
            was_admin_user=`echo ${item#-was_admin_user=}`
	elif [ `expr match "$item" '-was_admin_password'` != 0 ]; then
           was_admin_password=`echo ${item#-was_admin_password=}`
	elif [ `expr match "$item" '-user'` != 0 ]; then
           user=`echo ${item#-user=}`
	elif [ `expr match "$item" '-password'` != 0 ]; then
           password=`echo ${item#-password=}`
	elif [ `expr match "$item" '-APP_NAME'` != 0 ]; then
           APP_NAME=`echo ${item#-APP_NAME=}` 
	elif [ `expr match "$item" '-APP_MODULE'` != 0 ]; then
           APP_MODULE=`echo ${item#-APP_MODULE=}` 
	elif [ `expr match "$item" '-APP_EJB'` != 0 ]; then
           APP_EJB=`echo ${item#-APP_EJB=}` 
	elif [ `expr match "$item" '-APP_SERVICE'` != 0 ]; then
           APP_SERVICE=`echo ${item#-APP_SERVICE=}` 
	elif [ `expr match "$item" '-APP_PORT'` != 0 ]; then
           APP_PORT=`echo ${item#-APP_PORT=}` 
	elif [ `expr match "$item" '-APP_EPU'` != 0 ]; then
           APP_EPU=`echo ${item#-APP_EPU=}` 
	elif [ `expr match "$item" '-ssl_config'` != 0 ]; then
           ssl_config=`echo ${item#-ssl_config=}` 
	elif [ `expr match "$item" '-timeout'` != 0 ]; then
           timeout=`echo ${item#-timeout=}` 
	elif [ `expr match "$item" '-help'` != 0 ]; then
	    usage
	    exit 1
	else
	    echo "Execute the script with one of the options as shown below"
           usage
	    exit 1
       fi
done

getActualWASConfig


#
# Figure out users and passwords
#
if [ -n "$was_admin_user" ]; then
	if [ -z "$was_admin_password" ]; then
		# "Enter password for WebSphere Administrative user id \"${was_admin_user}\":"
		echo_message FEAT05200I "${was_admin_user}" 
		stty -echo
		read was_admin_password
		stty echo
		echo
	fi
	WSADMIN="wsadmin.sh -profileName $PROFILENAME -conntype SOAP -user ${was_admin_user} -password ${was_admin_password} -wsadmin_classpath $CLASSPATH "
else
	WSADMIN="wsadmin.sh -profileName $PROFILENAME -wsadmin_classpath $CLASSPATH "
fi

if [ -n "$user" -a -z "$password" ];then
	echo "Enter password for the user $user: " 
	stty -echo
	read password
	stty echo
	echo
fi

### The script will - 
### 1. Update the end-point URLs in Web Services Client bindings
### 2. Update the HTTP Authentication info in Web Services Client Security bindings
### 3. Update the SSL Configuration in WebServices Client Security Bindings
### Set constants #####################


### Step 1 & 2 & 3 - set endpoint URL, HTTP authentication, SSL authentication ##########################
if [ -n "$was_admin_user" ]; then
	updateEndPointOnly=false
else
	updateEndPointOnly=true
	user="user"
	password="password"	
	ssl_config="ssl_config"
fi
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/updateWSClientBindings.jacl $SERVERNAME $NODENAME $CELLNAME $APP_NAME $APP_MODULE $APP_EJB $APP_SERVICE $APP_PORT $APP_EPU $user $password $ssl_config $updateEndPointOnly $timeout

exit 0