#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2011, 2012
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: updateTransactionTimout.sh	
##   Description: Configures WAS transaction timeout.
##   Usage: updateTransactionTimout.sh 
##  -was_admin_user optional argument if WAS is security enabled
##  -was_admin_password optional argument if was_admin_user needs to be passed
##  -help prints the usage
##
#############################################################################

#
# setup solution environment
#
SCRIPT_DIR=`dirname ${0}`
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
	. ${SCRIPT_DIR}/pedigree-env.sh
else
	#"$0 : File not found ${SCRIPT_DIR}/pedigree-env.sh"
	exit 1
fi
PLATFORM=`/bin/uname`
if [ "$PLATFORM" = "SunOS" ];then
	AWK="awk -F."
else
	AWK="awk -F ".""
fi

usage()
{
  usage="\n\
  $0 '[options]'\n\
  Options:\n\
  -was_admin_user optional argument if WAS is security enabled \n\
  -was_admin_password optional argument if was_admin_user needs to be passed \n\
  -help prints the usage\n\
  none     update transaction service configuration"
  echo -e "Usage: $usage"
  return 0
}

unset was_admin_user
unset was_admin_password

for item in $*
do
	if [ `expr match "$item" '-was_admin_user'` != 0 ]; then
              was_admin_user=`echo ${item#-was_admin_user=}`
	elif [ `expr match "$item" '-was_admin_password='` != 0 ]; then
    	    was_admin_password=`echo ${item#-was_admin_password=}`
	elif [ `expr match "$item" '-help'` != 0 ]; then
		usage
		exit
	else
		echo "Execute the script with one of the options as shown below"
        usage
        exitError $E_OPTERROR
    fi
done

if [ -z "$SERVERNAME" -o -z "$NODENAME" -o -z "$CELLNAME" -o -z "$QUEUE_MANAGER" -o -z "$DBMS_ALIAS" \
    -o -z "$DBMS_ADMIN_USER" -o -z "$DBMS_ADMIN_PWD" -o -z "$DBMS_DB_NAME" -o \
    -z "$HOSTNAME" ]; then

   echo_message FEAT05208I "SERVERNAME=\"$SERVERNAME\" NODENAME=\"$NODENAME\" CELLNAME=\"$CELLNAME\" \
 QUEUE_MANAGER=\"$QUEUE_MANAGER\" DBMS_ALIAS=\"$DBMS_ALIAS\" DBMS_ADMIN_USER=\"$DBMS_ADMIN_USER\" \
 DBMS_ADMIN_PWD=\"$DBMS_ADMIN_PWD\" DBMS_DB_NAME=\"$DBMS_DB_NAME\" HOSTNAME=\"$HOSTNAME\""

	# Please check the following files: ...
	echo_message FEAT05212I "  $RFIDIC_SOLDIR/bin/pedigree-env.sh"
	exit ${E_ENVERROR}
fi

if [ -z "$NORFIDIC" ]; then
	getActualWASConfig
fi

#
# Figure out users and passwords
#
if [ -n "$was_admin_user" ]; then
	if [ -z "$was_admin_password" ]; then
		# "Enter password for WebSphere Administrative user id \"${was_admin_user}\":"
		echo_message FEAT05200I "${was_admin_user}" 
		stty -echo
		read was_admin_password
		stty echo
		echo
	fi
	WSADMIN="wsadmin.sh -profileName $PROFILENAME -conntype SOAP -user ${was_admin_user} -password ${was_admin_password} -wsadmin_classpath $CLASSPATH "
else
	WSADMIN="wsadmin.sh -profileName $PROFILENAME -wsadmin_classpath $CLASSPATH "
fi

if [ -n "$NORFIDIC" ]; then
	if [ -n "$was_admin_user" ]; then
		WSADMIN="${WAS_HOME}/bin/wsadmin.sh -profileName $PROFILENAME -conntype SOAP -user ${was_admin_user} -password ${was_admin_password} -wsadmin_classpath $CLASSPATH "
	else
		WSADMIN="${WAS_HOME}/bin/wsadmin.sh -profileName $PROFILENAME -wsadmin_classpath $CLASSPATH "
	fi
fi

# Call JACL
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/updateTransactionSvcConf.jacl $SERVERNAME $NODENAME $CELLNAME