#!/bin/sh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# 5724-O98 (C) COPYRIGHT International Business Machines Corp. 2006 - 2008
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# yamqput.sh - "Yet Another MQ Queue Put" puts the contents of a file onto a MQ queue.
#
# Usage: yamqput.sh [options] url file
#	url - destination information passed using a URL syntax
#         e.g. jms:/queue?queueManager=QUEUE_MGR&queue=QUEUE
#   file - the utility reads this file and puts the contents on the queue
#   options:
#        -v  (verbose) outputs debugging information
#
# Environment:
#   MQ_HOME                # 
#   MQ_JAVA_INSTALL_PATH   # default /opt/mqm/java
#   MQ_JAVA_DATA_PATH      # default /var/mqm
#   MQ_JAVA_LIB_PATH       # default /opt/mqm/java/lib
#   Does not require an ITS environment.
#

SCRIPT_DIR=`dirname $0`
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
    . $SCRIPT_DIR/pedigree-env.sh
elif [ -z "$MQ_HOME" ]; then
	echo -e "MQ_HOME variable not set. Please set MQ_HOME to the MQ installation directory."
    exit 1
fi

usage="\n\
$0 [options] url file\n\
  options: \n\
    -v  (verbose) outputs debugging information\n\
  url - destination information passed using a URL syntax (you need to escape\n\
  the '&' special character, or pass the entire URL between quotes)\n\
  e.g. 'jms:/queue?queueManager=RFIDICv11.QUEUE.MANAGER&queue=PedigreeEventIn'\n\
  file - the utility reads this file and puts the contents on the queue\n\
"

# Extract command line args
verbose=0
while getopts ":mnopq:rsv" Option
do
  case $Option in
    v) verbose=1;;
    h) echo -e "$usage"; exit -2;;
    *) echo "Incorrect option $1"; echo -e "$usage"; exit 1;;
  esac
done

# Decrements the argument pointer so it points to next argument
shift `expr $OPTIND - 1`

# this script is in $TOOLS_HOME/bin, resolve TOOLS_HOME
if [ -z "$TOOLS_HOME" -o ! -d "$TOOLS_HOME" ] ; then
	## resolve links - $0 may be a link to tools home
	PRG="$0"
	progname=`basename "$0"`
	
	# need this for relative symlinks
	while [ -h "$PRG" ] ; do
		ls=`ls -ld "$PRG"`
		link=`expr "$ls" : '.*-> \(.*\)$'`
		if expr "$link" : '/.*' > /dev/null; then
			PRG="$link"
		else
			PRG=`dirname "$PRG"`"/$link"
		fi
	done
	TOOLS_HOME=`dirname "$PRG"`/..
	
	# make it fully qualified
	TOOLS_HOME=`cd "$TOOLS_HOME" && pwd`
fi

if [ -z "$MQ_JAVA_INSTALL_PATH" ]; then
	MQ_JAVA_INSTALL_PATH=${MQ_HOME}/java
fi
if [ -z "$MQ_JAVA_DATA_PATH" ]; then
	MQ_JAVA_DATA_PATH=/var/mqm
	if [ ! -d "$MQ_JAVA_DATA_PATH" ]; then
		echo -e "Cannot find $MQ_JAVA_DATA_PATH.  Create the director, or set"
		"MQ_JAVA_DATA_PATH before calling this script."
		exit 1
	fi
fi
if [ -z "$MQ_JAVA_LIB_PATH" ]; then
	MQ_JAVA_LIB_PATH=${MQ_HOME}/java/lib
fi

#
# set CLASSPATH
#
CLASSPATH=
current_dir=`pwd`
cd $TOOLS_HOME/lib
for i in *.jar
do
	CLASSPATH=$CLASSPATH:$TOOLS_HOME/lib/$i
done
CLASSPATH=$CLASSPATH:$MQ_JAVA_INSTALL_PATH/lib/com.ibm.mq.jar:$MQ_JAVA_INSTALL_PATH/lib/com.ibm.mqjms.jar
cd ${current_dir}

if [ $verbose -eq 1 ] ; then
    echo MQ_HOME=$MQ_HOME
    echo MQ_JAVA_INSTALL_PATH=$MQ_JAVA_INSTALL_PATH
    echo MQ_JAVA_DATA_PATH=$MQ_JAVA_DATA_PATH
    echo MQ_JAVA_LIB_PATH=$MQ_JAVA_LIB_PATH
    echo CLASSPATH=$CLASSPATH 
    echo
fi

${JAVA_HOME}/bin/java -Djava.library.path=$MQ_JAVA_LIB_PATH -DMQJMS_LOG_DIR=$MQ_JAVA_DATA_PATH/log \
  -DMQJMS_TRACE_DIR=$MQ_JAVA_DATA_PATH/trace -DMQJMS_TRACE_LEVEL=$MQJMS_TRACE_LEVEL \
  -cp ${CLASSPATH} com.ibm.rfidic.tools.mq.YaMQPut $*
